class pyqtSignal():
 def connect(self, targetSignal): pass
 def emit(self, *args): pass
from QtCore import *

class KTextEditor():
    """"""
    def createPlugin(self):
        '''static QObject KTextEditor.createPlugin()'''
        return QObject()
    def editor(self):
        '''static str KTextEditor.editor()'''
        return str()
    class Document(KParts.ReadWritePart):
        """"""
        def __init__(self):
            '''QObject KTextEditor.Document.__init__()'''
            return QObject()
        def variableInterface(self):
            '''KTextEditor.VariableInterface KTextEditor.Document.variableInterface()'''
            return KTextEditor.VariableInterface()
        def textHintInterface(self):
            '''KTextEditor.TextHintInterface KTextEditor.Document.textHintInterface()'''
            return KTextEditor.TextHintInterface()
        def templateInterface(self):
            '''KTextEditor.TemplateInterface KTextEditor.Document.templateInterface()'''
            return KTextEditor.TemplateInterface()
        def smartInterface(self):
            '''KTextEditor.SmartInterface KTextEditor.Document.smartInterface()'''
            return KTextEditor.SmartInterface()
        def searchInterface(self):
            '''KTextEditor.SearchInterface KTextEditor.Document.searchInterface()'''
            return KTextEditor.SearchInterface()
        def modificationInterface(self):
            '''KTextEditor.ModificationInterface KTextEditor.Document.modificationInterface()'''
            return KTextEditor.ModificationInterface()
        def markInterface(self):
            '''KTextEditor.MarkInterface KTextEditor.Document.markInterface()'''
            return KTextEditor.MarkInterface()
        def setOpeningErrorMessage(self):
            '''QString KTextEditor.Document.setOpeningErrorMessage()'''
            return QString()
        def setOpeningError(self):
            '''bool KTextEditor.Document.setOpeningError()'''
            return bool()
        def openingErrorMessage(self):
            '''QString KTextEditor.Document.openingErrorMessage()'''
            return QString()
        def openingError(self):
            '''bool KTextEditor.Document.openingError()'''
            return bool()
        def suppressOpeningErrorDialogs(self):
            '''bool KTextEditor.Document.suppressOpeningErrorDialogs()'''
            return bool()
        def setSuppressOpeningErrorDialogs(self):
            '''bool KTextEditor.Document.setSuppressOpeningErrorDialogs()'''
            return bool()
        highlightingModeChanged = pyqtSignal() # void highlightingModeChanged(KTextEditor::Document *) - signal
        modeChanged = pyqtSignal() # void modeChanged(KTextEditor::Document *) - signal
        def modeSection(self):
            '''abstract int KTextEditor.Document.modeSection()'''
            return int()
        def highlightingModeSection(self):
            '''abstract int KTextEditor.Document.highlightingModeSection()'''
            return int()
        def setHighlightingMode(self):
            '''abstract QString KTextEditor.Document.setHighlightingMode()'''
            return QString()
        def setMode(self):
            '''abstract QString KTextEditor.Document.setMode()'''
            return QString()
        def highlightingModes(self):
            '''abstract QStringList KTextEditor.Document.highlightingModes()'''
            return QStringList()
        def modes(self):
            '''abstract QStringList KTextEditor.Document.modes()'''
            return QStringList()
        def highlightingMode(self):
            '''abstract QString KTextEditor.Document.highlightingMode()'''
            return QString()
        def mode(self):
            '''abstract QString KTextEditor.Document.mode()'''
            return QString()
        aboutToClose = pyqtSignal() # void aboutToClose(KTextEditor::Document *) - signal
        textRemoved = pyqtSignal() # void textRemoved(KTextEditor::Document *,const KTextEditor::Rangeamp;) - signal
        textInserted = pyqtSignal() # void textInserted(KTextEditor::Document *,const KTextEditor::Rangeamp;) - signal
        textChanged = pyqtSignal() # void textChanged(KTextEditor::Document *) - signal
        textChanged = pyqtSignal() # void textChanged(KTextEditor::Document *,const KTextEditor::Rangeamp;,const KTextEditor::Rangeamp;) - signal
        def removeLine(self):
            '''abstract int KTextEditor.Document.removeLine()'''
            return int()
        def insertLines(self):
            '''abstract QStringList KTextEditor.Document.insertLines()'''
            return QStringList()
        def insertLine(self):
            '''abstract QString KTextEditor.Document.insertLine()'''
            return QString()
        def cursorInText(self):
            '''KTextEditor.Cursor KTextEditor.Document.cursorInText()'''
            return KTextEditor.Cursor()
        def removeText(self):
            '''abstract bool KTextEditor.Document.removeText()'''
            return bool()
        def replaceText(self):
            '''bool KTextEditor.Document.replaceText()'''
            return bool()
        def replaceText(self):
            '''bool KTextEditor.Document.replaceText()'''
            return bool()
        def insertText(self):
            '''abstract bool KTextEditor.Document.insertText()'''
            return bool()
        def insertText(self):
            '''abstract bool KTextEditor.Document.insertText()'''
            return bool()
        def clear(self):
            '''abstract bool KTextEditor.Document.clear()'''
            return bool()
        def setText(self):
            '''abstract QString KTextEditor.Document.setText()'''
            return QString()
        def setText(self):
            '''abstract QStringList KTextEditor.Document.setText()'''
            return QStringList()
        def endOfLine(self):
            '''int KTextEditor.Document.endOfLine()'''
            return int()
        def lineLength(self):
            '''abstract int KTextEditor.Document.lineLength()'''
            return int()
        def isEmpty(self):
            '''bool KTextEditor.Document.isEmpty()'''
            return bool()
        def totalCharacters(self):
            '''abstract int KTextEditor.Document.totalCharacters()'''
            return int()
        def documentRange(self):
            '''KTextEditor.Range KTextEditor.Document.documentRange()'''
            return KTextEditor.Range()
        def documentEnd(self):
            '''abstract KTextEditor.Cursor KTextEditor.Document.documentEnd()'''
            return KTextEditor.Cursor()
        def lines(self):
            '''abstract int KTextEditor.Document.lines()'''
            return int()
        def line(self):
            '''abstract int KTextEditor.Document.line()'''
            return int()
        def textLines(self):
            '''abstract bool KTextEditor.Document.textLines()'''
            return bool()
        def character(self):
            '''abstract KTextEditor.Cursor KTextEditor.Document.character()'''
            return KTextEditor.Cursor()
        def text(self):
            '''abstract QString KTextEditor.Document.text()'''
            return QString()
        def text(self):
            '''abstract bool KTextEditor.Document.text()'''
            return bool()
        def endEditing(self):
            '''abstract bool KTextEditor.Document.endEditing()'''
            return bool()
        def startEditing(self):
            '''abstract bool KTextEditor.Document.startEditing()'''
            return bool()
        def documentSaveAs(self):
            '''abstract bool KTextEditor.Document.documentSaveAs()'''
            return bool()
        def documentSave(self):
            '''abstract bool KTextEditor.Document.documentSave()'''
            return bool()
        def documentReload(self):
            '''abstract bool KTextEditor.Document.documentReload()'''
            return bool()
        def encoding(self):
            '''abstract QString KTextEditor.Document.encoding()'''
            return QString()
        def setEncoding(self):
            '''abstract QString KTextEditor.Document.setEncoding()'''
            return QString()
        modifiedChanged = pyqtSignal() # void modifiedChanged(KTextEditor::Document *) - signal
        documentUrlChanged = pyqtSignal() # void documentUrlChanged(KTextEditor::Document *) - signal
        documentNameChanged = pyqtSignal() # void documentNameChanged(KTextEditor::Document *) - signal
        def mimeType(self):
            '''abstract QString KTextEditor.Document.mimeType()'''
            return QString()
        def documentName(self):
            '''abstract QString KTextEditor.Document.documentName()'''
            return QString()
        viewCreated = pyqtSignal() # void viewCreated(KTextEditor::Document *,KTextEditor::View *) - signal
        def views(self):
            '''abstract list-of-KTextEditor.View KTextEditor.Document.views()'''
            return [KTextEditor.View()]
        def activeView(self):
            '''abstract KTextEditor.View KTextEditor.Document.activeView()'''
            return KTextEditor.View()
        def createView(self):
            '''abstract QWidget KTextEditor.Document.createView()'''
            return QWidget()
        def editor(self):
            '''abstract KTextEditor.Editor KTextEditor.Document.editor()'''
            return KTextEditor.Editor()
    class Attribute():
        """"""
        class Effects():
            """"""
            def __init__(self):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__init__()'''
                return KTextEditor.Attribute.Effects()
            def __init__(self):
                '''int KTextEditor.Attribute.Effects.__init__()'''
                return int()
            def __init__(self):
                '''void KTextEditor.Attribute.Effects.__init__()'''
            def __bool__(self):
                '''int KTextEditor.Attribute.Effects.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KTextEditor.Attribute.Effects.__ne__(KTextEditor.Attribute.Effects f)'''
                return bool()
            def __eq__(self, f):
                '''bool KTextEditor.Attribute.Effects.__eq__(KTextEditor.Attribute.Effects f)'''
                return bool()
            def __invert__(self):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__invert__()'''
                return KTextEditor.Attribute.Effects()
            def __and__(self, mask):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__and__(int mask)'''
                return KTextEditor.Attribute.Effects()
            def __xor__(self, f):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__xor__(KTextEditor.Attribute.Effects f)'''
                return KTextEditor.Attribute.Effects()
            def __xor__(self, f):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__xor__(int f)'''
                return KTextEditor.Attribute.Effects()
            def __or__(self, f):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__or__(KTextEditor.Attribute.Effects f)'''
                return KTextEditor.Attribute.Effects()
            def __or__(self, f):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__or__(int f)'''
                return KTextEditor.Attribute.Effects()
            def __int__(self):
                '''int KTextEditor.Attribute.Effects.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__ixor__(KTextEditor.Attribute.Effects f)'''
                return KTextEditor.Attribute.Effects()
            def __ior__(self, f):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__ior__(KTextEditor.Attribute.Effects f)'''
                return KTextEditor.Attribute.Effects()
            def __iand__(self, mask):
                '''KTextEditor.Attribute.Effects KTextEditor.Attribute.Effects.__iand__(int mask)'''
                return KTextEditor.Attribute.Effects()
    class View(QWidget, KXMLGUIClient):
        """"""
        # Enum KTextEditor.View.EditMode
        EditInsert = 0
        EditOverwrite = 0
    
        def __init__(self):
            '''QWidget KTextEditor.View.__init__()'''
            return QWidget()
        def textHintInterface(self):
            '''KTextEditor.TextHintInterface KTextEditor.View.textHintInterface()'''
            return KTextEditor.TextHintInterface()
        def sessionConfigInterface(self):
            '''KTextEditor.SessionConfigInterface KTextEditor.View.sessionConfigInterface()'''
            return KTextEditor.SessionConfigInterface()
        def codeCompletionInterface(self):
            '''KTextEditor.CodeCompletionInterface KTextEditor.View.codeCompletionInterface()'''
            return KTextEditor.CodeCompletionInterface()
        def insertText(self):
            '''QString KTextEditor.View.insertText()'''
            return QString()
        selectionChanged = pyqtSignal() # void selectionChanged(KTextEditor::View *) - signal
        def blockSelection(self):
            '''abstract bool KTextEditor.View.blockSelection()'''
            return bool()
        def setBlockSelection(self):
            '''abstract bool KTextEditor.View.setBlockSelection()'''
            return bool()
        def removeSelectionText(self):
            '''abstract bool KTextEditor.View.removeSelectionText()'''
            return bool()
        def removeSelection(self):
            '''abstract bool KTextEditor.View.removeSelection()'''
            return bool()
        def selectionText(self):
            '''abstract QString KTextEditor.View.selectionText()'''
            return QString()
        def selectionRange(self):
            '''abstract KTextEditor.Range KTextEditor.View.selectionRange()'''
            return KTextEditor.Range()
        def selection(self):
            '''abstract bool KTextEditor.View.selection()'''
            return bool()
        def setSelection(self):
            '''abstract KTextEditor.Range KTextEditor.View.setSelection()'''
            return KTextEditor.Range()
        def setSelection(self):
            '''bool KTextEditor.View.setSelection()'''
            return bool()
        mousePositionChanged = pyqtSignal() # void mousePositionChanged(KTextEditor::View *,const KTextEditor::Cursoramp;) - signal
        def setMouseTrackingEnabled(self):
            '''abstract bool KTextEditor.View.setMouseTrackingEnabled()'''
            return bool()
        def mouseTrackingEnabled(self):
            '''abstract bool KTextEditor.View.mouseTrackingEnabled()'''
            return bool()
        horizontalScrollPositionChanged = pyqtSignal() # void horizontalScrollPositionChanged(KTextEditor::View *) - signal
        verticalScrollPositionChanged = pyqtSignal() # void verticalScrollPositionChanged(KTextEditor::View *,const KTextEditor::Cursoramp;) - signal
        cursorPositionChanged = pyqtSignal() # void cursorPositionChanged(KTextEditor::View *,const KTextEditor::Cursoramp;) - signal
        def cursorPositionCoordinates(self):
            '''abstract QPoint KTextEditor.View.cursorPositionCoordinates()'''
            return QPoint()
        def cursorToCoordinate(self):
            '''abstract KTextEditor.Cursor KTextEditor.View.cursorToCoordinate()'''
            return KTextEditor.Cursor()
        def cursorPositionVirtual(self):
            '''abstract KTextEditor.Cursor KTextEditor.View.cursorPositionVirtual()'''
            return KTextEditor.Cursor()
        def cursorPosition(self):
            '''abstract KTextEditor.Cursor KTextEditor.View.cursorPosition()'''
            return KTextEditor.Cursor()
        def setCursorPosition(self):
            '''abstract KTextEditor.Cursor KTextEditor.View.setCursorPosition()'''
            return KTextEditor.Cursor()
        contextMenuAboutToShow = pyqtSignal() # void contextMenuAboutToShow(KTextEditor::View *,QMenu *) - signal
        def defaultContextMenu(self):
            '''abstract QMenu KTextEditor.View.defaultContextMenu()'''
            return QMenu()
        def contextMenu(self):
            '''abstract QMenu KTextEditor.View.contextMenu()'''
            return QMenu()
        def setContextMenu(self):
            '''abstract QMenu KTextEditor.View.setContextMenu()'''
            return QMenu()
        textInserted = pyqtSignal() # void textInserted(KTextEditor::View *,const KTextEditor::Cursoramp;,const QStringamp;) - signal
        informationMessage = pyqtSignal() # void informationMessage(KTextEditor::View *,const QStringamp;) - signal
        viewEditModeChanged = pyqtSignal() # void viewEditModeChanged(KTextEditor::View *,KTextEditor::View::EditMode) - signal
        viewModeChanged = pyqtSignal() # void viewModeChanged(KTextEditor::View *) - signal
        focusOut = pyqtSignal() # void focusOut(KTextEditor::View *) - signal
        focusIn = pyqtSignal() # void focusIn(KTextEditor::View *) - signal
        def viewEditMode(self):
            '''abstract KTextEditor.View.EditMode KTextEditor.View.viewEditMode()'''
            return KTextEditor.View.EditMode()
        def viewMode(self):
            '''abstract QString KTextEditor.View.viewMode()'''
            return QString()
        def isActiveView(self):
            '''bool KTextEditor.View.isActiveView()'''
            return bool()
        def document(self):
            '''abstract KTextEditor.Document KTextEditor.View.document()'''
            return KTextEditor.Document()
    class ConfigInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.ConfigInterface.__init__()'''
        def setConfigValue(self):
            '''abstract QVariant KTextEditor.ConfigInterface.setConfigValue()'''
            return QVariant()
        def configValue(self):
            '''abstract QString KTextEditor.ConfigInterface.configValue()'''
            return QString()
        def configKeys(self):
            '''abstract QStringList KTextEditor.ConfigInterface.configKeys()'''
            return QStringList()
    class Command():
        """"""
        def __init__(self):
            '''void KTextEditor.Command.__init__()'''
        def __init__(self):
            '''KTextEditor.Command KTextEditor.Command.__init__()'''
            return KTextEditor.Command()
        def help(self):
            '''abstract QString KTextEditor.Command.help()'''
            return QString()
        def exec_(self):
            '''abstract QString KTextEditor.Command.exec_()'''
            return QString()
        def cmds(self):
            '''abstract QStringList KTextEditor.Command.cmds()'''
            return QStringList()
    class SmartRange():
        """"""
        class InsertBehaviors():
            """"""
            def __init__(self):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__init__()'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __init__(self):
                '''int KTextEditor.SmartRange.InsertBehaviors.__init__()'''
                return int()
            def __init__(self):
                '''void KTextEditor.SmartRange.InsertBehaviors.__init__()'''
            def __bool__(self):
                '''int KTextEditor.SmartRange.InsertBehaviors.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KTextEditor.SmartRange.InsertBehaviors.__ne__(KTextEditor.SmartRange.InsertBehaviors f)'''
                return bool()
            def __eq__(self, f):
                '''bool KTextEditor.SmartRange.InsertBehaviors.__eq__(KTextEditor.SmartRange.InsertBehaviors f)'''
                return bool()
            def __invert__(self):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__invert__()'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __and__(self, mask):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__and__(int mask)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __xor__(self, f):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__xor__(KTextEditor.SmartRange.InsertBehaviors f)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __xor__(self, f):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__xor__(int f)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __or__(self, f):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__or__(KTextEditor.SmartRange.InsertBehaviors f)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __or__(self, f):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__or__(int f)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __int__(self):
                '''int KTextEditor.SmartRange.InsertBehaviors.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__ixor__(KTextEditor.SmartRange.InsertBehaviors f)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __ior__(self, f):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__ior__(KTextEditor.SmartRange.InsertBehaviors f)'''
                return KTextEditor.SmartRange.InsertBehaviors()
            def __iand__(self, mask):
                '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.InsertBehaviors.__iand__(int mask)'''
                return KTextEditor.SmartRange.InsertBehaviors()
    class Mark():
        """"""
        line = None # int - member
        type = None # int - member
        def __init__(self):
            '''void KTextEditor.Mark.__init__()'''
        def __init__(self):
            '''KTextEditor.Mark KTextEditor.Mark.__init__()'''
            return KTextEditor.Mark()
    class Attribute(QTextCharFormat):
        """"""
        # Enum KTextEditor.Attribute.Effect
        EffectNone = 0
        EffectFadeIn = 0
        EffectFadeOut = 0
        EffectPulse = 0
        EffectCycleGradient = 0
    
        # Enum KTextEditor.Attribute.ActivationType
        ActivateMouseIn = 0
        ActivateCaretIn = 0
    
        # Enum KTextEditor.Attribute.CustomProperties
        Outline = 0
        SelectedForeground = 0
        SelectedBackground = 0
        BackgroundFillWhitespace = 0
        AttributeDynamicEffect = 0
        AttributeInternalProperty = 0
        AttributeUserProperty = 0
    
        def __init__(self):
            '''void KTextEditor.Attribute.__init__()'''
        def __init__(self):
            '''KTextEditor.Attribute KTextEditor.Attribute.__init__()'''
            return KTextEditor.Attribute()
        def __iadd__(self):
            '''KTextEditor.Attribute KTextEditor.Attribute.__iadd__()'''
            return KTextEditor.Attribute()
        def setEffects(self):
            '''KTextEditor.Attribute.Effects KTextEditor.Attribute.setEffects()'''
            return KTextEditor.Attribute.Effects()
        def effects(self):
            '''KTextEditor.Attribute.Effects KTextEditor.Attribute.effects()'''
            return KTextEditor.Attribute.Effects()
        def setDynamicAttribute(self):
            '''unknown-type KTextEditor.Attribute.setDynamicAttribute()'''
            return unknown-type()
        def dynamicAttribute(self):
            '''KTextEditor.Attribute.ActivationType KTextEditor.Attribute.dynamicAttribute()'''
            return KTextEditor.Attribute.ActivationType()
        def clearAssociatedActions(self):
            '''void KTextEditor.Attribute.clearAssociatedActions()'''
        def associatedActions(self):
            '''list-of-KAction KTextEditor.Attribute.associatedActions()'''
            return [KAction()]
        def hasAnyProperty(self):
            '''bool KTextEditor.Attribute.hasAnyProperty()'''
            return bool()
        def clear(self):
            '''void KTextEditor.Attribute.clear()'''
        def setBackgroundFillWhitespace(self):
            '''bool KTextEditor.Attribute.setBackgroundFillWhitespace()'''
            return bool()
        def backgroundFillWhitespace(self):
            '''bool KTextEditor.Attribute.backgroundFillWhitespace()'''
            return bool()
        def setSelectedBackground(self):
            '''QBrush KTextEditor.Attribute.setSelectedBackground()'''
            return QBrush()
        def selectedBackground(self):
            '''QBrush KTextEditor.Attribute.selectedBackground()'''
            return QBrush()
        def setSelectedForeground(self):
            '''QBrush KTextEditor.Attribute.setSelectedForeground()'''
            return QBrush()
        def selectedForeground(self):
            '''QBrush KTextEditor.Attribute.selectedForeground()'''
            return QBrush()
        def setOutline(self):
            '''QBrush KTextEditor.Attribute.setOutline()'''
            return QBrush()
        def outline(self):
            '''QBrush KTextEditor.Attribute.outline()'''
            return QBrush()
        def setFontBold(self):
            '''bool KTextEditor.Attribute.setFontBold()'''
            return bool()
        def fontBold(self):
            '''bool KTextEditor.Attribute.fontBold()'''
            return bool()
    class CommandInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.CommandInterface.__init__()'''
        def __init__(self):
            '''KTextEditor.CommandInterface KTextEditor.CommandInterface.__init__()'''
            return KTextEditor.CommandInterface()
        def commandList(self):
            '''abstract QStringList KTextEditor.CommandInterface.commandList()'''
            return QStringList()
        def commands(self):
            '''abstract list-of-KTextEditor.Command KTextEditor.CommandInterface.commands()'''
            return [KTextEditor.Command()]
        def queryCommand(self):
            '''abstract QString KTextEditor.CommandInterface.queryCommand()'''
            return QString()
        def unregisterCommand(self):
            '''abstract KTextEditor.Command KTextEditor.CommandInterface.unregisterCommand()'''
            return KTextEditor.Command()
        def registerCommand(self):
            '''abstract KTextEditor.Command KTextEditor.CommandInterface.registerCommand()'''
            return KTextEditor.Command()
    class SmartInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.SmartInterface.__init__()'''
        def attributeNotDynamic(self):
            '''abstract unknown-type KTextEditor.SmartInterface.attributeNotDynamic()'''
            return unknown-type()
        def attributeDynamic(self):
            '''abstract unknown-type KTextEditor.SmartInterface.attributeDynamic()'''
            return unknown-type()
        def clearViewActions(self):
            '''abstract KTextEditor.View KTextEditor.SmartInterface.clearViewActions()'''
            return KTextEditor.View()
        def viewActions(self):
            '''abstract KTextEditor.View KTextEditor.SmartInterface.viewActions()'''
            return KTextEditor.View()
        def removeActionsFromView(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.removeActionsFromView()'''
            return KTextEditor.SmartRange()
        def addActionsToView(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.addActionsToView()'''
            return KTextEditor.SmartRange()
        def clearDocumentActions(self):
            '''abstract void KTextEditor.SmartInterface.clearDocumentActions()'''
        def documentActions(self):
            '''abstract list-of-KTextEditor.SmartRange KTextEditor.SmartInterface.documentActions()'''
            return [KTextEditor.SmartRange()]
        def removeActionsFromDocument(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.removeActionsFromDocument()'''
            return KTextEditor.SmartRange()
        def addActionsToDocument(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.addActionsToDocument()'''
            return KTextEditor.SmartRange()
        def clearViewHighlights(self):
            '''abstract KTextEditor.View KTextEditor.SmartInterface.clearViewHighlights()'''
            return KTextEditor.View()
        def viewHighlights(self):
            '''abstract KTextEditor.View KTextEditor.SmartInterface.viewHighlights()'''
            return KTextEditor.View()
        def removeHighlightFromView(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.removeHighlightFromView()'''
            return KTextEditor.SmartRange()
        def addHighlightToView(self):
            '''abstract bool KTextEditor.SmartInterface.addHighlightToView()'''
            return bool()
        def clearDocumentHighlights(self):
            '''abstract void KTextEditor.SmartInterface.clearDocumentHighlights()'''
        def documentHighlights(self):
            '''abstract list-of-KTextEditor.SmartRange KTextEditor.SmartInterface.documentHighlights()'''
            return [KTextEditor.SmartRange()]
        def removeHighlightFromDocument(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.removeHighlightFromDocument()'''
            return KTextEditor.SmartRange()
        def addHighlightToDocument(self):
            '''abstract bool KTextEditor.SmartInterface.addHighlightToDocument()'''
            return bool()
        def deleteRanges(self):
            '''abstract void KTextEditor.SmartInterface.deleteRanges()'''
        def unbindSmartRange(self):
            '''abstract KTextEditor.SmartRange KTextEditor.SmartInterface.unbindSmartRange()'''
            return KTextEditor.SmartRange()
        def newSmartRange(self):
            '''abstract KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartInterface.newSmartRange()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def newSmartRange(self):
            '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartInterface.newSmartRange()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def newSmartRange(self):
            '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartInterface.newSmartRange()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def newSmartRange(self):
            '''abstract KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartInterface.newSmartRange()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def deleteCursors(self):
            '''abstract void KTextEditor.SmartInterface.deleteCursors()'''
        def newSmartCursor(self):
            '''abstract KTextEditor.SmartCursor.InsertBehavior KTextEditor.SmartInterface.newSmartCursor()'''
            return KTextEditor.SmartCursor.InsertBehavior()
        def newSmartCursor(self):
            '''KTextEditor.SmartCursor.InsertBehavior KTextEditor.SmartInterface.newSmartCursor()'''
            return KTextEditor.SmartCursor.InsertBehavior()
        def translateFromRevision(self):
            '''KTextEditor.SmartCursor.InsertBehavior KTextEditor.SmartInterface.translateFromRevision()'''
            return KTextEditor.SmartCursor.InsertBehavior()
        def translateFromRevision(self):
            '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartInterface.translateFromRevision()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def clearRevision(self):
            '''void KTextEditor.SmartInterface.clearRevision()'''
        def useRevision(self):
            '''abstract int KTextEditor.SmartInterface.useRevision()'''
            return int()
        def releaseRevision(self):
            '''abstract int KTextEditor.SmartInterface.releaseRevision()'''
            return int()
        def currentRevision(self):
            '''abstract int KTextEditor.SmartInterface.currentRevision()'''
            return int()
        def setClearOnDocumentReload(self):
            '''bool KTextEditor.SmartInterface.setClearOnDocumentReload()'''
            return bool()
        def clearOnDocumentReload(self):
            '''bool KTextEditor.SmartInterface.clearOnDocumentReload()'''
            return bool()
        def clearSmartInterface(self):
            '''abstract void KTextEditor.SmartInterface.clearSmartInterface()'''
        def smartMutex(self):
            '''QMutex KTextEditor.SmartInterface.smartMutex()'''
            return QMutex()
    class CodeCompletionModel(QAbstractItemModel):
        """"""
        # Enum KTextEditor.CodeCompletionModel.InvocationType
        AutomaticInvocation = 0
        UserInvocation = 0
        ManualInvocation = 0
    
        # Enum KTextEditor.CodeCompletionModel.ExtraItemDataRoles
        CompletionRole = 0
        ScopeIndex = 0
        MatchQuality = 0
        SetMatchContext = 0
        HighlightingMethod = 0
        CustomHighlight = 0
        InheritanceDepth = 0
        IsExpandable = 0
        ExpandingWidget = 0
        ItemSelected = 0
        ArgumentHintDepth = 0
        BestMatchesCount = 0
        AccessibilityNext = 0
        AccessibilityPrevious = 0
        AccessibilityAccept = 0
    
        # Enum KTextEditor.CodeCompletionModel.HighlightMethod
        NoHighlighting = 0
        InternalHighlighting = 0
        CustomHighlighting = 0
    
        # Enum KTextEditor.CodeCompletionModel.CompletionProperty
        NoProperty = 0
        FirstProperty = 0
        Public = 0
        Protected = 0
        Private = 0
        Static = 0
        Const = 0
        Namespace = 0
        Class = 0
        Struct = 0
        Union = 0
        Function = 0
        Variable = 0
        Enum = 0
        Template = 0
        TypeAlias = 0
        Virtual = 0
        Override = 0
        Inline = 0
        Friend = 0
        Signal = 0
        Slot = 0
        LocalScope = 0
        NamespaceScope = 0
        GlobalScope = 0
        LastProperty = 0
    
        # Enum KTextEditor.CodeCompletionModel.Columns
        Prefix = 0
        Icon = 0
        Scope = 0
        Name = 0
        Arguments = 0
        Postfix = 0
    
        ColumnCount = None # int - member
        LastItemDataRole = None # int - member
        def __init__(self):
            '''QObject KTextEditor.CodeCompletionModel.__init__()'''
            return QObject()
        def rowCount(self):
            '''QModelIndex KTextEditor.CodeCompletionModel.rowCount()'''
            return QModelIndex()
        def parent(self):
            '''QModelIndex KTextEditor.CodeCompletionModel.parent()'''
            return QModelIndex()
        def itemData(self):
            '''QModelIndex KTextEditor.CodeCompletionModel.itemData()'''
            return QModelIndex()
        def index(self):
            '''QModelIndex KTextEditor.CodeCompletionModel.index()'''
            return QModelIndex()
        def columnCount(self):
            '''QModelIndex KTextEditor.CodeCompletionModel.columnCount()'''
            return QModelIndex()
        def executeCompletionItem(self):
            '''int KTextEditor.CodeCompletionModel.executeCompletionItem()'''
            return int()
        def completionInvoked(self):
            '''KTextEditor.CodeCompletionModel.InvocationType KTextEditor.CodeCompletionModel.completionInvoked()'''
            return KTextEditor.CodeCompletionModel.InvocationType()
        def setRowCount(self):
            '''int KTextEditor.CodeCompletionModel.setRowCount()'''
            return int()
    class ConfigPage(QWidget):
        """"""
        def __init__(self):
            '''QWidget KTextEditor.ConfigPage.__init__()'''
            return QWidget()
        changed = pyqtSignal() # void changed() - signal
        def defaults(self):
            '''abstract void KTextEditor.ConfigPage.defaults()'''
        def reset(self):
            '''abstract void KTextEditor.ConfigPage.reset()'''
        def apply(self):
            '''abstract void KTextEditor.ConfigPage.apply()'''
    class CommandExtension():
        """"""
        def __init__(self):
            '''void KTextEditor.CommandExtension.__init__()'''
        def __init__(self):
            '''KTextEditor.CommandExtension KTextEditor.CommandExtension.__init__()'''
            return KTextEditor.CommandExtension()
        def processText(self):
            '''abstract QString KTextEditor.CommandExtension.processText()'''
            return QString()
        def wantsToProcessText(self):
            '''abstract QString KTextEditor.CommandExtension.wantsToProcessText()'''
            return QString()
        def completionObject(self):
            '''abstract QString KTextEditor.CommandExtension.completionObject()'''
            return QString()
        def flagCompletions(self):
            '''abstract QStringList KTextEditor.CommandExtension.flagCompletions()'''
            return QStringList()
    class SmartCursorWatcher():
        """"""
        def __init__(self):
            '''void KTextEditor.SmartCursorWatcher.__init__()'''
        def __init__(self):
            '''KTextEditor.SmartCursorWatcher KTextEditor.SmartCursorWatcher.__init__()'''
            return KTextEditor.SmartCursorWatcher()
        def deleted(self):
            '''KTextEditor.SmartCursor KTextEditor.SmartCursorWatcher.deleted()'''
            return KTextEditor.SmartCursor()
        def characterInserted(self):
            '''bool KTextEditor.SmartCursorWatcher.characterInserted()'''
            return bool()
        def characterDeleted(self):
            '''bool KTextEditor.SmartCursorWatcher.characterDeleted()'''
            return bool()
        def positionDeleted(self):
            '''KTextEditor.SmartCursor KTextEditor.SmartCursorWatcher.positionDeleted()'''
            return KTextEditor.SmartCursor()
        def positionChanged(self):
            '''KTextEditor.SmartCursor KTextEditor.SmartCursorWatcher.positionChanged()'''
            return KTextEditor.SmartCursor()
        def setWantsDirectChanges(self):
            '''bool KTextEditor.SmartCursorWatcher.setWantsDirectChanges()'''
            return bool()
        def wantsDirectChanges(self):
            '''bool KTextEditor.SmartCursorWatcher.wantsDirectChanges()'''
            return bool()
    class SmartRangeWatcher():
        """"""
        def __init__(self):
            '''void KTextEditor.SmartRangeWatcher.__init__()'''
        def __init__(self):
            '''KTextEditor.SmartRangeWatcher KTextEditor.SmartRangeWatcher.__init__()'''
            return KTextEditor.SmartRangeWatcher()
        def rangeAttributeChanged(self):
            '''unknown-type KTextEditor.SmartRangeWatcher.rangeAttributeChanged()'''
            return unknown-type()
        def childRangeRemoved(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.childRangeRemoved()'''
            return KTextEditor.SmartRange()
        def childRangeInserted(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.childRangeInserted()'''
            return KTextEditor.SmartRange()
        def parentRangeChanged(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.parentRangeChanged()'''
            return KTextEditor.SmartRange()
        def rangeDeleted(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.rangeDeleted()'''
            return KTextEditor.SmartRange()
        def rangeEliminated(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.rangeEliminated()'''
            return KTextEditor.SmartRange()
        def caretExitedRange(self):
            '''KTextEditor.View KTextEditor.SmartRangeWatcher.caretExitedRange()'''
            return KTextEditor.View()
        def caretEnteredRange(self):
            '''KTextEditor.View KTextEditor.SmartRangeWatcher.caretEnteredRange()'''
            return KTextEditor.View()
        def mouseExitedRange(self):
            '''KTextEditor.View KTextEditor.SmartRangeWatcher.mouseExitedRange()'''
            return KTextEditor.View()
        def mouseEnteredRange(self):
            '''KTextEditor.View KTextEditor.SmartRangeWatcher.mouseEnteredRange()'''
            return KTextEditor.View()
        def rangeContentsChanged(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.rangeContentsChanged()'''
            return KTextEditor.SmartRange()
        def rangeContentsChanged(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.rangeContentsChanged()'''
            return KTextEditor.SmartRange()
        def rangePositionChanged(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRangeWatcher.rangePositionChanged()'''
            return KTextEditor.SmartRange()
        def setWantsDirectChanges(self):
            '''bool KTextEditor.SmartRangeWatcher.setWantsDirectChanges()'''
            return bool()
        def wantsDirectChanges(self):
            '''bool KTextEditor.SmartRangeWatcher.wantsDirectChanges()'''
            return bool()
    class Factory(KParts.Factory):
        """"""
        def __init__(self):
            '''QObject KTextEditor.Factory.__init__()'''
            return QObject()
        def editor(self):
            '''abstract KTextEditor.Editor KTextEditor.Factory.editor()'''
            return KTextEditor.Editor()
    class Plugin(QObject):
        """"""
        def __init__(self):
            '''QObject KTextEditor.Plugin.__init__()'''
            return QObject()
        def removeView(self):
            '''KTextEditor.View KTextEditor.Plugin.removeView()'''
            return KTextEditor.View()
        def addView(self):
            '''KTextEditor.View KTextEditor.Plugin.addView()'''
            return KTextEditor.View()
        def removeDocument(self):
            '''KTextEditor.Document KTextEditor.Plugin.removeDocument()'''
            return KTextEditor.Document()
        def addDocument(self):
            '''KTextEditor.Document KTextEditor.Plugin.addDocument()'''
            return KTextEditor.Document()
    class SearchInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.SearchInterface.__init__()'''
        def supportedSearchOptions(self):
            '''abstract KTextEditor.Search.SearchOptions KTextEditor.SearchInterface.supportedSearchOptions()'''
            return KTextEditor.Search.SearchOptions()
        def searchText(self):
            '''abstract KTextEditor.Search.SearchOptions KTextEditor.SearchInterface.searchText()'''
            return KTextEditor.Search.SearchOptions()
    class Search():
        """"""
        class SearchOptions():
            """"""
            def __init__(self):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__init__()'''
                return KTextEditor.Search.SearchOptions()
            def __init__(self):
                '''int KTextEditor.Search.SearchOptions.__init__()'''
                return int()
            def __init__(self):
                '''void KTextEditor.Search.SearchOptions.__init__()'''
            def __bool__(self):
                '''int KTextEditor.Search.SearchOptions.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KTextEditor.Search.SearchOptions.__ne__(KTextEditor.Search.SearchOptions f)'''
                return bool()
            def __eq__(self, f):
                '''bool KTextEditor.Search.SearchOptions.__eq__(KTextEditor.Search.SearchOptions f)'''
                return bool()
            def __invert__(self):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__invert__()'''
                return KTextEditor.Search.SearchOptions()
            def __and__(self, mask):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__and__(int mask)'''
                return KTextEditor.Search.SearchOptions()
            def __xor__(self, f):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__xor__(KTextEditor.Search.SearchOptions f)'''
                return KTextEditor.Search.SearchOptions()
            def __xor__(self, f):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__xor__(int f)'''
                return KTextEditor.Search.SearchOptions()
            def __or__(self, f):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__or__(KTextEditor.Search.SearchOptions f)'''
                return KTextEditor.Search.SearchOptions()
            def __or__(self, f):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__or__(int f)'''
                return KTextEditor.Search.SearchOptions()
            def __int__(self):
                '''int KTextEditor.Search.SearchOptions.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__ixor__(KTextEditor.Search.SearchOptions f)'''
                return KTextEditor.Search.SearchOptions()
            def __ior__(self, f):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__ior__(KTextEditor.Search.SearchOptions f)'''
                return KTextEditor.Search.SearchOptions()
            def __iand__(self, mask):
                '''KTextEditor.Search.SearchOptions KTextEditor.Search.SearchOptions.__iand__(int mask)'''
                return KTextEditor.Search.SearchOptions()
    class CodeCompletionInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.CodeCompletionInterface.__init__()'''
        def __init__(self):
            '''KTextEditor.CodeCompletionInterface KTextEditor.CodeCompletionInterface.__init__()'''
            return KTextEditor.CodeCompletionInterface()
        def setAutomaticInvocationEnabled(self):
            '''abstract bool KTextEditor.CodeCompletionInterface.setAutomaticInvocationEnabled()'''
            return bool()
        def isAutomaticInvocationEnabled(self):
            '''abstract bool KTextEditor.CodeCompletionInterface.isAutomaticInvocationEnabled()'''
            return bool()
        def unregisterCompletionModel(self):
            '''abstract KTextEditor.CodeCompletionModel KTextEditor.CodeCompletionInterface.unregisterCompletionModel()'''
            return KTextEditor.CodeCompletionModel()
        def registerCompletionModel(self):
            '''abstract KTextEditor.CodeCompletionModel KTextEditor.CodeCompletionInterface.registerCompletionModel()'''
            return KTextEditor.CodeCompletionModel()
        def forceCompletion(self):
            '''abstract void KTextEditor.CodeCompletionInterface.forceCompletion()'''
        def abortCompletion(self):
            '''abstract void KTextEditor.CodeCompletionInterface.abortCompletion()'''
        def startCompletion(self):
            '''abstract KTextEditor.CodeCompletionModel KTextEditor.CodeCompletionInterface.startCompletion()'''
            return KTextEditor.CodeCompletionModel()
        def isCompletionActive(self):
            '''abstract bool KTextEditor.CodeCompletionInterface.isCompletionActive()'''
            return bool()
    class TemplateInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.TemplateInterface.__init__()'''
        def insertTemplateTextImplementation(self):
            '''abstract dict-of-QString-QString KTextEditor.TemplateInterface.insertTemplateTextImplementation()'''
            return dict-of-QString-QString()
        def insertTemplateText(self):
            '''dict-of-QString-QString KTextEditor.TemplateInterface.insertTemplateText()'''
            return dict-of-QString-QString()
        def expandMacros(self):
            '''static QWidget KTextEditor.TemplateInterface.expandMacros()'''
            return QWidget()
    class TextHintInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.TextHintInterface.__init__()'''
        def needTextHint(self):
            '''abstract QString KTextEditor.TextHintInterface.needTextHint()'''
            return QString()
        def disableTextHints(self):
            '''abstract void KTextEditor.TextHintInterface.disableTextHints()'''
        def enableTextHints(self):
            '''abstract int KTextEditor.TextHintInterface.enableTextHints()'''
            return int()
    class VariableInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.VariableInterface.__init__()'''
        def variableChanged(self):
            '''abstract QString KTextEditor.VariableInterface.variableChanged()'''
            return QString()
        def variable(self):
            '''abstract QString KTextEditor.VariableInterface.variable()'''
            return QString()
    class CodeCompletionModel():
        """"""
        class HighlightMethods():
            """"""
            def __init__(self):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__init__()'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __init__(self):
                '''int KTextEditor.CodeCompletionModel.HighlightMethods.__init__()'''
                return int()
            def __init__(self):
                '''void KTextEditor.CodeCompletionModel.HighlightMethods.__init__()'''
            def __bool__(self):
                '''int KTextEditor.CodeCompletionModel.HighlightMethods.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KTextEditor.CodeCompletionModel.HighlightMethods.__ne__(KTextEditor.CodeCompletionModel.HighlightMethods f)'''
                return bool()
            def __eq__(self, f):
                '''bool KTextEditor.CodeCompletionModel.HighlightMethods.__eq__(KTextEditor.CodeCompletionModel.HighlightMethods f)'''
                return bool()
            def __invert__(self):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__invert__()'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __and__(self, mask):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__and__(int mask)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __xor__(self, f):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__xor__(KTextEditor.CodeCompletionModel.HighlightMethods f)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __xor__(self, f):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__xor__(int f)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __or__(self, f):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__or__(KTextEditor.CodeCompletionModel.HighlightMethods f)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __or__(self, f):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__or__(int f)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __int__(self):
                '''int KTextEditor.CodeCompletionModel.HighlightMethods.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__ixor__(KTextEditor.CodeCompletionModel.HighlightMethods f)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __ior__(self, f):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__ior__(KTextEditor.CodeCompletionModel.HighlightMethods f)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
            def __iand__(self, mask):
                '''KTextEditor.CodeCompletionModel.HighlightMethods KTextEditor.CodeCompletionModel.HighlightMethods.__iand__(int mask)'''
                return KTextEditor.CodeCompletionModel.HighlightMethods()
    class SmartCursor(KTextEditor.Cursor):
        """"""
        # Enum KTextEditor.SmartCursor.InsertBehavior
        StayOnInsert = 0
        MoveOnInsert = 0
    
        # Enum KTextEditor.SmartCursor.AdvanceMode
        ByCharacter = 0
        ByCursorPosition = 0
    
        def __init__(self):
            '''KTextEditor.SmartCursor.InsertBehavior KTextEditor.SmartCursor.__init__()'''
            return KTextEditor.SmartCursor.InsertBehavior()
        def setWatcher(self):
            '''abstract KTextEditor.SmartCursorWatcher KTextEditor.SmartCursor.setWatcher()'''
            return KTextEditor.SmartCursorWatcher()
        def watcher(self):
            '''abstract KTextEditor.SmartCursorWatcher KTextEditor.SmartCursor.watcher()'''
            return KTextEditor.SmartCursorWatcher()
        def deleteNotifier(self):
            '''abstract void KTextEditor.SmartCursor.deleteNotifier()'''
        def notifier(self):
            '''abstract KTextEditor.SmartCursorNotifier KTextEditor.SmartCursor.notifier()'''
            return KTextEditor.SmartCursorNotifier()
        def hasNotifier(self):
            '''abstract bool KTextEditor.SmartCursor.hasNotifier()'''
            return bool()
        def setInsertBehavior(self):
            '''KTextEditor.SmartCursor.InsertBehavior KTextEditor.SmartCursor.setInsertBehavior()'''
            return KTextEditor.SmartCursor.InsertBehavior()
        def insertBehavior(self):
            '''KTextEditor.SmartCursor.InsertBehavior KTextEditor.SmartCursor.insertBehavior()'''
            return KTextEditor.SmartCursor.InsertBehavior()
        def advance(self):
            '''KTextEditor.SmartCursor.AdvanceMode KTextEditor.SmartCursor.advance()'''
            return KTextEditor.SmartCursor.AdvanceMode()
        def insertText(self):
            '''bool KTextEditor.SmartCursor.insertText()'''
            return bool()
        def character(self):
            '''QChar KTextEditor.SmartCursor.character()'''
            return QChar()
        def isValid(self):
            '''bool KTextEditor.SmartCursor.isValid()'''
            return bool()
        def atEndOfDocument(self):
            '''bool KTextEditor.SmartCursor.atEndOfDocument()'''
            return bool()
        def atEndOfLine(self):
            '''bool KTextEditor.SmartCursor.atEndOfLine()'''
            return bool()
        def document(self):
            '''KTextEditor.Document KTextEditor.SmartCursor.document()'''
            return KTextEditor.Document()
        def smartRange(self):
            '''KTextEditor.SmartRange KTextEditor.SmartCursor.smartRange()'''
            return KTextEditor.SmartRange()
        def toSmartCursor(self):
            '''KTextEditor.SmartCursor KTextEditor.SmartCursor.toSmartCursor()'''
            return KTextEditor.SmartCursor()
        def isSmartCursor(self):
            '''bool KTextEditor.SmartCursor.isSmartCursor()'''
            return bool()
    class MarkInterface():
        """"""
        # Enum KTextEditor.MarkInterface.MarkChangeAction
        MarkAdded = 0
        MarkRemoved = 0
    
        # Enum KTextEditor.MarkInterface.MarkTypes
        markType01 = 0
        markType02 = 0
        markType03 = 0
        markType04 = 0
        markType05 = 0
        markType06 = 0
        markType07 = 0
        markType08 = 0
        markType09 = 0
        markType10 = 0
        markType11 = 0
        markType12 = 0
        markType13 = 0
        markType14 = 0
        markType15 = 0
        markType16 = 0
        markType17 = 0
        markType18 = 0
        markType19 = 0
        markType20 = 0
        markType21 = 0
        markType22 = 0
        markType23 = 0
        markType24 = 0
        markType25 = 0
        markType26 = 0
        markType27 = 0
        markType28 = 0
        markType29 = 0
        markType30 = 0
        markType31 = 0
        markType32 = 0
        Bookmark = 0
        BreakpointActive = 0
        BreakpointReached = 0
        BreakpointDisabled = 0
        Execution = 0
        Warning = 0
        Error = 0
    
        def __init__(self):
            '''void KTextEditor.MarkInterface.__init__()'''
        def markChanged(self):
            '''abstract KTextEditor.MarkInterface.MarkChangeAction KTextEditor.MarkInterface.markChanged()'''
            return KTextEditor.MarkInterface.MarkChangeAction()
        def editableMarks(self):
            '''abstract int KTextEditor.MarkInterface.editableMarks()'''
            return int()
        def setEditableMarks(self):
            '''abstract int KTextEditor.MarkInterface.setEditableMarks()'''
            return int()
        def markDescription(self):
            '''abstract KTextEditor.MarkInterface.MarkTypes KTextEditor.MarkInterface.markDescription()'''
            return KTextEditor.MarkInterface.MarkTypes()
        def setMarkDescription(self):
            '''abstract QString KTextEditor.MarkInterface.setMarkDescription()'''
            return QString()
        def markPixmap(self):
            '''abstract KTextEditor.MarkInterface.MarkTypes KTextEditor.MarkInterface.markPixmap()'''
            return KTextEditor.MarkInterface.MarkTypes()
        def setMarkPixmap(self):
            '''abstract QPixmap KTextEditor.MarkInterface.setMarkPixmap()'''
            return QPixmap()
        def marksChanged(self):
            '''abstract KTextEditor.Document KTextEditor.MarkInterface.marksChanged()'''
            return KTextEditor.Document()
        def reservedMarkersCount(self):
            '''static int KTextEditor.MarkInterface.reservedMarkersCount()'''
            return int()
        def clearMarks(self):
            '''abstract void KTextEditor.MarkInterface.clearMarks()'''
        def marks(self):
            '''abstract unknown-type KTextEditor.MarkInterface.marks()'''
            return unknown-type()
        def removeMark(self):
            '''abstract int KTextEditor.MarkInterface.removeMark()'''
            return int()
        def addMark(self):
            '''abstract int KTextEditor.MarkInterface.addMark()'''
            return int()
        def clearMark(self):
            '''abstract int KTextEditor.MarkInterface.clearMark()'''
            return int()
        def setMark(self):
            '''abstract int KTextEditor.MarkInterface.setMark()'''
            return int()
        def mark(self):
            '''abstract int KTextEditor.MarkInterface.mark()'''
            return int()
    class Search():
        """"""
        # Enum KTextEditor.Search.SearchOptionsEnum
        Default = 0
        Regex = 0
        CaseInsensitive = 0
        Backwards = 0
        BlockInputRange = 0
        EscapeSequences = 0
        WholeWords = 0
        DotMatchesNewline = 0
    
    class EditorChooser(QWidget):
        """"""
        def __init__(self):
            '''QWidget KTextEditor.EditorChooser.__init__()'''
            return QWidget()
        changed = pyqtSignal() # void changed() - signal
        def editor(self):
            '''static bool KTextEditor.EditorChooser.editor()'''
            return bool()
        def writeAppSetting(self):
            '''QString KTextEditor.EditorChooser.writeAppSetting()'''
            return QString()
        def readAppSetting(self):
            '''QString KTextEditor.EditorChooser.readAppSetting()'''
            return QString()
    class SessionConfigInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.SessionConfigInterface.__init__()'''
        def writeSessionConfig(self):
            '''abstract KConfigGroup KTextEditor.SessionConfigInterface.writeSessionConfig()'''
            return KConfigGroup()
        def readSessionConfig(self):
            '''abstract KConfigGroup KTextEditor.SessionConfigInterface.readSessionConfig()'''
            return KConfigGroup()
    class Cursor():
        """"""
        def __init__(self):
            '''void KTextEditor.Cursor.__init__()'''
        def __init__(self):
            '''int KTextEditor.Cursor.__init__()'''
            return int()
        def __init__(self):
            '''KTextEditor.Cursor KTextEditor.Cursor.__init__()'''
            return KTextEditor.Cursor()
        def cursorChangedDirectly(self):
            '''KTextEditor.Cursor KTextEditor.Cursor.cursorChangedDirectly()'''
            return KTextEditor.Cursor()
        def setRange(self):
            '''KTextEditor.Range KTextEditor.Cursor.setRange()'''
            return KTextEditor.Range()
        def range(self):
            '''KTextEditor.Range KTextEditor.Cursor.range()'''
            return KTextEditor.Range()
        def position(self):
            '''int KTextEditor.Cursor.position()'''
            return int()
        def atStartOfDocument(self):
            '''bool KTextEditor.Cursor.atStartOfDocument()'''
            return bool()
        def atStartOfLine(self):
            '''bool KTextEditor.Cursor.atStartOfLine()'''
            return bool()
        def setColumn(self):
            '''int KTextEditor.Cursor.setColumn()'''
            return int()
        def column(self):
            '''int KTextEditor.Cursor.column()'''
            return int()
        def setLine(self):
            '''int KTextEditor.Cursor.setLine()'''
            return int()
        def line(self):
            '''int KTextEditor.Cursor.line()'''
            return int()
        def setPosition(self):
            '''KTextEditor.Cursor KTextEditor.Cursor.setPosition()'''
            return KTextEditor.Cursor()
        def setPosition(self):
            '''int KTextEditor.Cursor.setPosition()'''
            return int()
        def start(self):
            '''static KTextEditor.Cursor KTextEditor.Cursor.start()'''
            return KTextEditor.Cursor()
        def invalid(self):
            '''static KTextEditor.Cursor KTextEditor.Cursor.invalid()'''
            return KTextEditor.Cursor()
        def toSmartCursor(self):
            '''KTextEditor.SmartCursor KTextEditor.Cursor.toSmartCursor()'''
            return KTextEditor.SmartCursor()
        def isSmartCursor(self):
            '''bool KTextEditor.Cursor.isSmartCursor()'''
            return bool()
        def isValid(self):
            '''bool KTextEditor.Cursor.isValid()'''
            return bool()
    class CodeCompletionModel():
        """"""
        class CompletionProperties():
            """"""
            def __init__(self):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__init__()'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __init__(self):
                '''int KTextEditor.CodeCompletionModel.CompletionProperties.__init__()'''
                return int()
            def __init__(self):
                '''void KTextEditor.CodeCompletionModel.CompletionProperties.__init__()'''
            def __bool__(self):
                '''int KTextEditor.CodeCompletionModel.CompletionProperties.__bool__()'''
                return int()
            def __ne__(self, f):
                '''bool KTextEditor.CodeCompletionModel.CompletionProperties.__ne__(KTextEditor.CodeCompletionModel.CompletionProperties f)'''
                return bool()
            def __eq__(self, f):
                '''bool KTextEditor.CodeCompletionModel.CompletionProperties.__eq__(KTextEditor.CodeCompletionModel.CompletionProperties f)'''
                return bool()
            def __invert__(self):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__invert__()'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __and__(self, mask):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__and__(int mask)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __xor__(self, f):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__xor__(KTextEditor.CodeCompletionModel.CompletionProperties f)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __xor__(self, f):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__xor__(int f)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __or__(self, f):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__or__(KTextEditor.CodeCompletionModel.CompletionProperties f)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __or__(self, f):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__or__(int f)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __int__(self):
                '''int KTextEditor.CodeCompletionModel.CompletionProperties.__int__()'''
                return int()
            def __ixor__(self, f):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__ixor__(KTextEditor.CodeCompletionModel.CompletionProperties f)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __ior__(self, f):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__ior__(KTextEditor.CodeCompletionModel.CompletionProperties f)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
            def __iand__(self, mask):
                '''KTextEditor.CodeCompletionModel.CompletionProperties KTextEditor.CodeCompletionModel.CompletionProperties.__iand__(int mask)'''
                return KTextEditor.CodeCompletionModel.CompletionProperties()
    class SmartRange(KTextEditor.Range):
        """"""
        # Enum KTextEditor.SmartRange.InsertBehavior
        DoNotExpand = 0
        ExpandLeft = 0
        ExpandRight = 0
    
        def __init__(self):
            '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.__init__()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def createNotifier(self):
            '''abstract KTextEditor.SmartRangeNotifier KTextEditor.SmartRange.createNotifier()'''
            return KTextEditor.SmartRangeNotifier()
        def checkFeedback(self):
            '''void KTextEditor.SmartRange.checkFeedback()'''
        def rangeChanged(self):
            '''KTextEditor.Range KTextEditor.SmartRange.rangeChanged()'''
            return KTextEditor.Range()
        def removeWatcher(self):
            '''KTextEditor.SmartRangeWatcher KTextEditor.SmartRange.removeWatcher()'''
            return KTextEditor.SmartRangeWatcher()
        def addWatcher(self):
            '''KTextEditor.SmartRangeWatcher KTextEditor.SmartRange.addWatcher()'''
            return KTextEditor.SmartRangeWatcher()
        def watchers(self):
            '''list-of-KTextEditor.SmartRangeWatcher KTextEditor.SmartRange.watchers()'''
            return [KTextEditor.SmartRangeWatcher()]
        def deletePrimaryNotifier(self):
            '''void KTextEditor.SmartRange.deletePrimaryNotifier()'''
        def removeNotifier(self):
            '''KTextEditor.SmartRangeNotifier KTextEditor.SmartRange.removeNotifier()'''
            return KTextEditor.SmartRangeNotifier()
        def addNotifier(self):
            '''KTextEditor.SmartRangeNotifier KTextEditor.SmartRange.addNotifier()'''
            return KTextEditor.SmartRangeNotifier()
        def notifiers(self):
            '''list-of-KTextEditor.SmartRangeNotifier KTextEditor.SmartRange.notifiers()'''
            return [KTextEditor.SmartRangeNotifier()]
        def primaryNotifier(self):
            '''KTextEditor.SmartRangeNotifier KTextEditor.SmartRange.primaryNotifier()'''
            return KTextEditor.SmartRangeNotifier()
        def clearAssociatedActions(self):
            '''void KTextEditor.SmartRange.clearAssociatedActions()'''
        def associatedActions(self):
            '''list-of-KAction KTextEditor.SmartRange.associatedActions()'''
            return [KAction()]
        def dissociateAction(self):
            '''KAction KTextEditor.SmartRange.dissociateAction()'''
            return KAction()
        def associateAction(self):
            '''KAction KTextEditor.SmartRange.associateAction()'''
            return KAction()
        def setAttribute(self):
            '''unknown-type KTextEditor.SmartRange.setAttribute()'''
            return unknown-type()
        def attribute(self):
            '''unknown-type KTextEditor.SmartRange.attribute()'''
            return unknown-type()
        def deepestRangeContaining(self):
            '''unknown-type KTextEditor.SmartRange.deepestRangeContaining()'''
            return unknown-type()
        def firstRangeContaining(self):
            '''KTextEditor.Cursor KTextEditor.SmartRange.firstRangeContaining()'''
            return KTextEditor.Cursor()
        def mostSpecificRange(self):
            '''KTextEditor.Range KTextEditor.SmartRange.mostSpecificRange()'''
            return KTextEditor.Range()
        def childAfter(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.childAfter()'''
            return KTextEditor.SmartRange()
        def childBefore(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.childBefore()'''
            return KTextEditor.SmartRange()
        def clearAndDeleteChildRanges(self):
            '''void KTextEditor.SmartRange.clearAndDeleteChildRanges()'''
        def deleteChildRanges(self):
            '''void KTextEditor.SmartRange.deleteChildRanges()'''
        def clearChildRanges(self):
            '''void KTextEditor.SmartRange.clearChildRanges()'''
        def childRanges(self):
            '''list-of-KTextEditor.SmartRange KTextEditor.SmartRange.childRanges()'''
            return [KTextEditor.SmartRange()]
        def topParentRange(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.topParentRange()'''
            return KTextEditor.SmartRange()
        def depth(self):
            '''int KTextEditor.SmartRange.depth()'''
            return int()
        def hasParent(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.hasParent()'''
            return KTextEditor.SmartRange()
        def setParentRange(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.setParentRange()'''
            return KTextEditor.SmartRange()
        def parentRange(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.parentRange()'''
            return KTextEditor.SmartRange()
        def setInsertBehavior(self):
            '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.setInsertBehavior()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def insertBehavior(self):
            '''KTextEditor.SmartRange.InsertBehaviors KTextEditor.SmartRange.insertBehavior()'''
            return KTextEditor.SmartRange.InsertBehaviors()
        def removeText(self):
            '''bool KTextEditor.SmartRange.removeText()'''
            return bool()
        def replaceText(self):
            '''bool KTextEditor.SmartRange.replaceText()'''
            return bool()
        def text(self):
            '''bool KTextEditor.SmartRange.text()'''
            return bool()
        def document(self):
            '''KTextEditor.Document KTextEditor.SmartRange.document()'''
            return KTextEditor.Document()
        def expandToRange(self):
            '''KTextEditor.Range KTextEditor.SmartRange.expandToRange()'''
            return KTextEditor.Range()
        def confineToRange(self):
            '''KTextEditor.Range KTextEditor.SmartRange.confineToRange()'''
            return KTextEditor.Range()
        def smartEnd(self):
            '''KTextEditor.SmartCursor KTextEditor.SmartRange.smartEnd()'''
            return KTextEditor.SmartCursor()
        def smartStart(self):
            '''KTextEditor.SmartCursor KTextEditor.SmartRange.smartStart()'''
            return KTextEditor.SmartCursor()
        def setRange(self):
            '''KTextEditor.Range KTextEditor.SmartRange.setRange()'''
            return KTextEditor.Range()
        def toSmartRange(self):
            '''KTextEditor.SmartRange KTextEditor.SmartRange.toSmartRange()'''
            return KTextEditor.SmartRange()
        def isSmartRange(self):
            '''bool KTextEditor.SmartRange.isSmartRange()'''
            return bool()
    class ContainerInterface():
        """"""
        def __init__(self):
            '''void KTextEditor.ContainerInterface.__init__()'''
        def __init__(self):
            '''KTextEditor.ContainerInterface KTextEditor.ContainerInterface.__init__()'''
            return KTextEditor.ContainerInterface()
        def container(self):
            '''abstract QObject KTextEditor.ContainerInterface.container()'''
            return QObject()
        def setContainer(self):
            '''abstract QObject KTextEditor.ContainerInterface.setContainer()'''
            return QObject()
    class ModificationInterface():
        """"""
        # Enum KTextEditor.ModificationInterface.ModifiedOnDiskReason
        OnDiskUnmodified = 0
        OnDiskModified = 0
        OnDiskCreated = 0
        OnDiskDeleted = 0
    
        def __init__(self):
            '''void KTextEditor.ModificationInterface.__init__()'''
        def modifiedOnDisk(self):
            '''abstract KTextEditor.ModificationInterface.ModifiedOnDiskReason KTextEditor.ModificationInterface.modifiedOnDisk()'''
            return KTextEditor.ModificationInterface.ModifiedOnDiskReason()
        def slotModifiedOnDisk(self):
            '''abstract KTextEditor.View KTextEditor.ModificationInterface.slotModifiedOnDisk()'''
            return KTextEditor.View()
        def setModifiedOnDiskWarning(self):
            '''abstract bool KTextEditor.ModificationInterface.setModifiedOnDiskWarning()'''
            return bool()
        def setModifiedOnDisk(self):
            '''abstract KTextEditor.ModificationInterface.ModifiedOnDiskReason KTextEditor.ModificationInterface.setModifiedOnDisk()'''
            return KTextEditor.ModificationInterface.ModifiedOnDiskReason()
    class Range():
        """"""
        def __init__(self):
            '''void KTextEditor.Range.__init__()'''
        def __init__(self):
            '''KTextEditor.Cursor KTextEditor.Range.__init__()'''
            return KTextEditor.Cursor()
        def __init__(self):
            '''int KTextEditor.Range.__init__()'''
            return int()
        def __init__(self):
            '''int KTextEditor.Range.__init__()'''
            return int()
        def __init__(self):
            '''int KTextEditor.Range.__init__()'''
            return int()
        def __init__(self):
            '''KTextEditor.Range KTextEditor.Range.__init__()'''
            return KTextEditor.Range()
        def __init__(self):
            '''KTextEditor.Cursor KTextEditor.Range.__init__()'''
            return KTextEditor.Cursor()
        def rangeChanged(self):
            '''KTextEditor.Range KTextEditor.Range.rangeChanged()'''
            return KTextEditor.Range()
        def encompass(self):
            '''KTextEditor.Range KTextEditor.Range.encompass()'''
            return KTextEditor.Range()
        def intersect(self):
            '''KTextEditor.Range KTextEditor.Range.intersect()'''
            return KTextEditor.Range()
        def boundaryOnLine(self):
            '''int KTextEditor.Range.boundaryOnLine()'''
            return int()
        def boundaryAtCursor(self):
            '''KTextEditor.Cursor KTextEditor.Range.boundaryAtCursor()'''
            return KTextEditor.Cursor()
        def positionRelativeToLine(self):
            '''int KTextEditor.Range.positionRelativeToLine()'''
            return int()
        def positionRelativeToCursor(self):
            '''KTextEditor.Cursor KTextEditor.Range.positionRelativeToCursor()'''
            return KTextEditor.Cursor()
        def overlapsColumn(self):
            '''int KTextEditor.Range.overlapsColumn()'''
            return int()
        def overlapsLine(self):
            '''int KTextEditor.Range.overlapsLine()'''
            return int()
        def overlaps(self):
            '''KTextEditor.Range KTextEditor.Range.overlaps()'''
            return KTextEditor.Range()
        def containsLine(self):
            '''int KTextEditor.Range.containsLine()'''
            return int()
        def contains(self):
            '''KTextEditor.Range KTextEditor.Range.contains()'''
            return KTextEditor.Range()
        def contains(self):
            '''KTextEditor.Cursor KTextEditor.Range.contains()'''
            return KTextEditor.Cursor()
        def isEmpty(self):
            '''bool KTextEditor.Range.isEmpty()'''
            return bool()
        def columnWidth(self):
            '''int KTextEditor.Range.columnWidth()'''
            return int()
        def numberOfLines(self):
            '''int KTextEditor.Range.numberOfLines()'''
            return int()
        def onSingleLine(self):
            '''bool KTextEditor.Range.onSingleLine()'''
            return bool()
        def confineToRange(self):
            '''KTextEditor.Range KTextEditor.Range.confineToRange()'''
            return KTextEditor.Range()
        def expandToRange(self):
            '''KTextEditor.Range KTextEditor.Range.expandToRange()'''
            return KTextEditor.Range()
        def setRange(self):
            '''KTextEditor.Range KTextEditor.Range.setRange()'''
            return KTextEditor.Range()
        def setRange(self):
            '''KTextEditor.Cursor KTextEditor.Range.setRange()'''
            return KTextEditor.Cursor()
        def setBothColumns(self):
            '''int KTextEditor.Range.setBothColumns()'''
            return int()
        def setBothLines(self):
            '''int KTextEditor.Range.setBothLines()'''
            return int()
        def end(self):
            '''KTextEditor.Cursor KTextEditor.Range.end()'''
            return KTextEditor.Cursor()
        def start(self):
            '''KTextEditor.Cursor KTextEditor.Range.start()'''
            return KTextEditor.Cursor()
        def toSmartRange(self):
            '''KTextEditor.SmartRange KTextEditor.Range.toSmartRange()'''
            return KTextEditor.SmartRange()
        def isSmartRange(self):
            '''bool KTextEditor.Range.isSmartRange()'''
            return bool()
        def invalid(self):
            '''static KTextEditor.Range KTextEditor.Range.invalid()'''
            return KTextEditor.Range()
        def isValid(self):
            '''bool KTextEditor.Range.isValid()'''
            return bool()
    class SmartCursorNotifier(QObject):
        """"""
        def __init__(self):
            '''void KTextEditor.SmartCursorNotifier.__init__()'''
        deleted = pyqtSignal() # void deleted(KTextEditor::SmartCursor *) - signal
        characterInserted = pyqtSignal() # void characterInserted(KTextEditor::SmartCursor *,bool) - signal
        characterDeleted = pyqtSignal() # void characterDeleted(KTextEditor::SmartCursor *,bool) - signal
        positionDeleted = pyqtSignal() # void positionDeleted(KTextEditor::SmartCursor *) - signal
        positionChanged = pyqtSignal() # void positionChanged(KTextEditor::SmartCursor *) - signal
        def setWantsDirectChanges(self):
            '''bool KTextEditor.SmartCursorNotifier.setWantsDirectChanges()'''
            return bool()
        def wantsDirectChanges(self):
            '''bool KTextEditor.SmartCursorNotifier.wantsDirectChanges()'''
            return bool()
    class Editor(QObject):
        """"""
        def __init__(self):
            '''QObject KTextEditor.Editor.__init__()'''
            return QObject()
        documentCreated = pyqtSignal() # void documentCreated(KTextEditor::Editor *,KTextEditor::Document *) - signal
        def configPageIcon(self):
            '''abstract int KTextEditor.Editor.configPageIcon()'''
            return int()
        def configPageFullName(self):
            '''abstract int KTextEditor.Editor.configPageFullName()'''
            return int()
        def configPageName(self):
            '''abstract int KTextEditor.Editor.configPageName()'''
            return int()
        def configPage(self):
            '''abstract QWidget KTextEditor.Editor.configPage()'''
            return QWidget()
        def configPages(self):
            '''abstract int KTextEditor.Editor.configPages()'''
            return int()
        def configDialog(self):
            '''abstract QWidget KTextEditor.Editor.configDialog()'''
            return QWidget()
        def configDialogSupported(self):
            '''abstract bool KTextEditor.Editor.configDialogSupported()'''
            return bool()
        def writeConfig(self):
            '''abstract KConfig KTextEditor.Editor.writeConfig()'''
            return KConfig()
        def readConfig(self):
            '''abstract KConfig KTextEditor.Editor.readConfig()'''
            return KConfig()
        def aboutData(self):
            '''abstract KAboutData KTextEditor.Editor.aboutData()'''
            return KAboutData()
        def documents(self):
            '''abstract list-of-KTextEditor.Document KTextEditor.Editor.documents()'''
            return [KTextEditor.Document()]
        def createDocument(self):
            '''abstract QObject KTextEditor.Editor.createDocument()'''
            return QObject()
    class SmartRangeNotifier(QObject):
        """"""
        def __init__(self):
            '''void KTextEditor.SmartRangeNotifier.__init__()'''
        rangeAttributeChanged = pyqtSignal() # void rangeAttributeChanged(KTextEditor::SmartRange *,KTextEditor::Attribute::Ptr,KTextEditor::Attribute::Ptr) - signal
        childRangeRemoved = pyqtSignal() # void childRangeRemoved(KTextEditor::SmartRange *,KTextEditor::SmartRange *) - signal
        childRangeInserted = pyqtSignal() # void childRangeInserted(KTextEditor::SmartRange *,KTextEditor::SmartRange *) - signal
        parentRangeChanged = pyqtSignal() # void parentRangeChanged(KTextEditor::SmartRange *,KTextEditor::SmartRange *,KTextEditor::SmartRange *) - signal
        rangeDeleted = pyqtSignal() # void rangeDeleted(KTextEditor::SmartRange *) - signal
        rangeEliminated = pyqtSignal() # void rangeEliminated(KTextEditor::SmartRange *) - signal
        caretExitedRange = pyqtSignal() # void caretExitedRange(KTextEditor::SmartRange *,KTextEditor::View *) - signal
        caretEnteredRange = pyqtSignal() # void caretEnteredRange(KTextEditor::SmartRange *,KTextEditor::View *) - signal
        mouseExitedRange = pyqtSignal() # void mouseExitedRange(KTextEditor::SmartRange *,KTextEditor::View *) - signal
        mouseEnteredRange = pyqtSignal() # void mouseEnteredRange(KTextEditor::SmartRange *,KTextEditor::View *) - signal
        rangeContentsChanged = pyqtSignal() # void rangeContentsChanged(KTextEditor::SmartRange *) - signal
        rangeContentsChanged = pyqtSignal() # void rangeContentsChanged(KTextEditor::SmartRange *,KTextEditor::SmartRange *) - signal
        rangePositionChanged = pyqtSignal() # void rangePositionChanged(KTextEditor::SmartRange *) - signal
        def setWantsDirectChanges(self):
            '''bool KTextEditor.SmartRangeNotifier.setWantsDirectChanges()'''
            return bool()
        def wantsDirectChanges(self):
            '''bool KTextEditor.SmartRangeNotifier.wantsDirectChanges()'''
            return bool()





"""A collection of string operations (most are no longer used).

Warning: most of the code you see here isn't normally used nowadays.
Beginning with Python 1.6, many of these functions are implemented as
methods on the standard string object. They used to be implemented by
a built-in module called strop, but strop is now obsolete itself.

Public module variables:

whitespace -- a string containing all characters considered whitespace
lowercase -- a string containing all characters considered lowercase letters
uppercase -- a string containing all characters considered uppercase letters
letters -- a string containing all characters considered letters
digits -- a string containing all characters considered decimal digits
hexdigits -- a string containing all characters considered hexadecimal digits
octdigits -- a string containing all characters considered octal digits
punctuation -- a string containing all characters considered punctuation
printable -- a string containing all characters considered printable

"""

# Some strings for ctype-style character classification
whitespace = ' \t\n\r\v\f'
lowercase = 'abcdefghijklmnopqrstuvwxyz'
uppercase = 'ABCDEFGHIJKLMNOPQRSTUVWXYZ'
letters = lowercase + uppercase
ascii_lowercase = lowercase
ascii_uppercase = uppercase
ascii_letters = ascii_lowercase + ascii_uppercase
digits = '0123456789'
hexdigits = digits + 'abcdef' + 'ABCDEF'
octdigits = '01234567'
punctuation = """!"#$%&'()*+,-./:;<=>?@[\]^_`{|}~"""
printable = digits + letters + punctuation + whitespace

# Case conversion helpers
# Use str to convert Unicode literal in case of -U
l = map(chr, xrange(256))
_idmap = str('').join(l)
del l

# Functions which aren't available as string methods.

# Capitalize the words in a string, e.g. " aBc  dEf " -> "Abc Def".
def capwords(s, sep=None):
    """capwords(s [,sep]) -> string

    Split the argument into words using split, capitalize each
    word using capitalize, and join the capitalized words using
    join.  If the optional second argument sep is absent or None,
    runs of whitespace characters are replaced by a single space
    and leading and trailing whitespace are removed, otherwise
    sep is used to split and join the words.

    """
    return (sep or ' ').join(x.capitalize() for x in s.split(sep))


# Construct a translation string
_idmapL = None
def maketrans(fromstr, tostr):
    """maketrans(frm, to) -> string

    Return a translation table (a string of 256 bytes long)
    suitable for use in string.translate.  The strings frm and to
    must be of the same length.

    """
    if len(fromstr) != len(tostr):
        raise ValueError, "maketrans arguments must have same length"
    global _idmapL
    if not _idmapL:
        _idmapL = list(_idmap)
    L = _idmapL[:]
    fromstr = map(ord, fromstr)
    for i in range(len(fromstr)):
        L[fromstr[i]] = tostr[i]
    return ''.join(L)



####################################################################
import re as _re

class _multimap:
    """Helper class for combining multiple mappings.

    Used by .{safe_,}substitute() to combine the mapping and keyword
    arguments.
    """
    def __init__(self, primary, secondary):
        self._primary = primary
        self._secondary = secondary

    def __getitem__(self, key):
        try:
            return self._primary[key]
        except KeyError:
            return self._secondary[key]


class _TemplateMetaclass(type):
    pattern = r"""
    %(delim)s(?:
      (?P<escaped>%(delim)s) |   # Escape sequence of two delimiters
      (?P<named>%(id)s)      |   # delimiter and a Python identifier
      {(?P<braced>%(id)s)}   |   # delimiter and a braced identifier
      (?P<invalid>)              # Other ill-formed delimiter exprs
    )
    """

    def __init__(cls, name, bases, dct):
        super(_TemplateMetaclass, cls).__init__(name, bases, dct)
        if 'pattern' in dct:
            pattern = cls.pattern
        else:
            pattern = _TemplateMetaclass.pattern % {
                'delim' : _re.escape(cls.delimiter),
                'id'    : cls.idpattern,
                }
        cls.pattern = _re.compile(pattern, _re.IGNORECASE | _re.VERBOSE)


class Template:
    """A string class for supporting $-substitutions."""
    __metaclass__ = _TemplateMetaclass

    delimiter = '$'
    idpattern = r'[_a-z][_a-z0-9]*'

    def __init__(self, template):
        self.template = template

    # Search for $$, $identifier, ${identifier}, and any bare $'s

    def _invalid(self, mo):
        i = mo.start('invalid')
        lines = self.template[:i].splitlines(True)
        if not lines:
            colno = 1
            lineno = 1
        else:
            colno = i - len(''.join(lines[:-1]))
            lineno = len(lines)
        raise ValueError('Invalid placeholder in string: line %d, col %d' %
                         (lineno, colno))

    def substitute(self, *args, **kws):
        if len(args) > 1:
            raise TypeError('Too many positional arguments')
        if not args:
            mapping = kws
        elif kws:
            mapping = _multimap(kws, args[0])
        else:
            mapping = args[0]
        # Helper function for .sub()
        def convert(mo):
            # Check the most common path first.
            named = mo.group('named') or mo.group('braced')
            if named is not None:
                val = mapping[named]
                # We use this idiom instead of str() because the latter will
                # fail if val is a Unicode containing non-ASCII characters.
                return '%s' % (val,)
            if mo.group('escaped') is not None:
                return self.delimiter
            if mo.group('invalid') is not None:
                self._invalid(mo)
            raise ValueError('Unrecognized named group in pattern',
                             self.pattern)
        return self.pattern.sub(convert, self.template)

    def safe_substitute(self, *args, **kws):
        if len(args) > 1:
            raise TypeError('Too many positional arguments')
        if not args:
            mapping = kws
        elif kws:
            mapping = _multimap(kws, args[0])
        else:
            mapping = args[0]
        # Helper function for .sub()
        def convert(mo):
            named = mo.group('named')
            if named is not None:
                try:
                    # We use this idiom instead of str() because the latter
                    # will fail if val is a Unicode containing non-ASCII
                    return '%s' % (mapping[named],)
                except KeyError:
                    return self.delimiter + named
            braced = mo.group('braced')
            if braced is not None:
                try:
                    return '%s' % (mapping[braced],)
                except KeyError:
                    return self.delimiter + '{' + braced + '}'
            if mo.group('escaped') is not None:
                return self.delimiter
            if mo.group('invalid') is not None:
                return self.delimiter
            raise ValueError('Unrecognized named group in pattern',
                             self.pattern)
        return self.pattern.sub(convert, self.template)



####################################################################
# NOTE: Everything below here is deprecated.  Use string methods instead.
# This stuff will go away in Python 3.0.

# Backward compatible names for exceptions
index_error = ValueError
atoi_error = ValueError
atof_error = ValueError
atol_error = ValueError

# convert UPPER CASE letters to lower case
def lower(s):
    """lower(s) -> string

    Return a copy of the string s converted to lowercase.

    """
    return s.lower()

# Convert lower case letters to UPPER CASE
def upper(s):
    """upper(s) -> string

    Return a copy of the string s converted to uppercase.

    """
    return s.upper()

# Swap lower case letters and UPPER CASE
def swapcase(s):
    """swapcase(s) -> string

    Return a copy of the string s with upper case characters
    converted to lowercase and vice versa.

    """
    return s.swapcase()

# Strip leading and trailing tabs and spaces
def strip(s, chars=None):
    """strip(s [,chars]) -> string

    Return a copy of the string s with leading and trailing
    whitespace removed.
    If chars is given and not None, remove characters in chars instead.
    If chars is unicode, S will be converted to unicode before stripping.

    """
    return s.strip(chars)

# Strip leading tabs and spaces
def lstrip(s, chars=None):
    """lstrip(s [,chars]) -> string

    Return a copy of the string s with leading whitespace removed.
    If chars is given and not None, remove characters in chars instead.

    """
    return s.lstrip(chars)

# Strip trailing tabs and spaces
def rstrip(s, chars=None):
    """rstrip(s [,chars]) -> string

    Return a copy of the string s with trailing whitespace removed.
    If chars is given and not None, remove characters in chars instead.

    """
    return s.rstrip(chars)


# Split a string into a list of space/tab-separated words
def split(s, sep=None, maxsplit=-1):
    """split(s [,sep [,maxsplit]]) -> list of strings

    Return a list of the words in the string s, using sep as the
    delimiter string.  If maxsplit is given, splits at no more than
    maxsplit places (resulting in at most maxsplit+1 words).  If sep
    is not specified or is None, any whitespace string is a separator.

    (split and splitfields are synonymous)

    """
    return s.split(sep, maxsplit)
splitfields = split

# Split a string into a list of space/tab-separated words
def rsplit(s, sep=None, maxsplit=-1):
    """rsplit(s [,sep [,maxsplit]]) -> list of strings

    Return a list of the words in the string s, using sep as the
    delimiter string, starting at the end of the string and working
    to the front.  If maxsplit is given, at most maxsplit splits are
    done. If sep is not specified or is None, any whitespace string
    is a separator.
    """
    return s.rsplit(sep, maxsplit)

# Join fields with optional separator
def join(words, sep = ' '):
    """join(list [,sep]) -> string

    Return a string composed of the words in list, with
    intervening occurrences of sep.  The default separator is a
    single space.

    (joinfields and join are synonymous)

    """
    return sep.join(words)
joinfields = join

# Find substring, raise exception if not found
def index(s, *args):
    """index(s, sub [,start [,end]]) -> int

    Like find but raises ValueError when the substring is not found.

    """
    return s.index(*args)

# Find last substring, raise exception if not found
def rindex(s, *args):
    """rindex(s, sub [,start [,end]]) -> int

    Like rfind but raises ValueError when the substring is not found.

    """
    return s.rindex(*args)

# Count non-overlapping occurrences of substring
def count(s, *args):
    """count(s, sub[, start[,end]]) -> int

    Return the number of occurrences of substring sub in string
    s[start:end].  Optional arguments start and end are
    interpreted as in slice notation.

    """
    return s.count(*args)

# Find substring, return -1 if not found
def find(s, *args):
    """find(s, sub [,start [,end]]) -> in

    Return the lowest index in s where substring sub is found,
    such that sub is contained within s[start,end].  Optional
    arguments start and end are interpreted as in slice notation.

    Return -1 on failure.

    """
    return s.find(*args)

# Find last substring, return -1 if not found
def rfind(s, *args):
    """rfind(s, sub [,start [,end]]) -> int

    Return the highest index in s where substring sub is found,
    such that sub is contained within s[start,end].  Optional
    arguments start and end are interpreted as in slice notation.

    Return -1 on failure.

    """
    return s.rfind(*args)

# for a bit of speed
_float = float
_int = int
_long = long

# Convert string to float
def atof(s):
    """atof(s) -> float

    Return the floating point number represented by the string s.

    """
    return _float(s)


# Convert string to integer
def atoi(s , base=10):
    """atoi(s [,base]) -> int

    Return the integer represented by the string s in the given
    base, which defaults to 10.  The string s must consist of one
    or more digits, possibly preceded by a sign.  If base is 0, it
    is chosen from the leading characters of s, 0 for octal, 0x or
    0X for hexadecimal.  If base is 16, a preceding 0x or 0X is
    accepted.

    """
    return _int(s, base)


# Convert string to long integer
def atol(s, base=10):
    """atol(s [,base]) -> long

    Return the long integer represented by the string s in the
    given base, which defaults to 10.  The string s must consist
    of one or more digits, possibly preceded by a sign.  If base
    is 0, it is chosen from the leading characters of s, 0 for
    octal, 0x or 0X for hexadecimal.  If base is 16, a preceding
    0x or 0X is accepted.  A trailing L or l is not accepted,
    unless base is 0.

    """
    return _long(s, base)


# Left-justify a string
def ljust(s, width, *args):
    """ljust(s, width[, fillchar]) -> string

    Return a left-justified version of s, in a field of the
    specified width, padded with spaces as needed.  The string is
    never truncated.  If specified the fillchar is used instead of spaces.

    """
    return s.ljust(width, *args)

# Right-justify a string
def rjust(s, width, *args):
    """rjust(s, width[, fillchar]) -> string

    Return a right-justified version of s, in a field of the
    specified width, padded with spaces as needed.  The string is
    never truncated.  If specified the fillchar is used instead of spaces.

    """
    return s.rjust(width, *args)

# Center a string
def center(s, width, *args):
    """center(s, width[, fillchar]) -> string

    Return a center version of s, in a field of the specified
    width. padded with spaces as needed.  The string is never
    truncated.  If specified the fillchar is used instead of spaces.

    """
    return s.center(width, *args)

# Zero-fill a number, e.g., (12, 3) --> '012' and (-3, 3) --> '-03'
# Decadent feature: the argument may be a string or a number
# (Use of this is deprecated; it should be a string as with ljust c.s.)
def zfill(x, width):
    """zfill(x, width) -> string

    Pad a numeric string x with zeros on the left, to fill a field
    of the specified width.  The string x is never truncated.

    """
    if not isinstance(x, basestring):
        x = repr(x)
    return x.zfill(width)

# Expand tabs in a string.
# Doesn't take non-printing chars into account, but does understand \n.
def expandtabs(s, tabsize=8):
    """expandtabs(s [,tabsize]) -> string

    Return a copy of the string s with all tab characters replaced
    by the appropriate number of spaces, depending on the current
    column, and the tabsize (default 8).

    """
    return s.expandtabs(tabsize)

# Character translation through look-up table.
def translate(s, table, deletions=""):
    """translate(s,table [,deletions]) -> string

    Return a copy of the string s, where all characters occurring
    in the optional argument deletions are removed, and the
    remaining characters have been mapped through the given
    translation table, which must be a string of length 256.  The
    deletions argument is not allowed for Unicode strings.

    """
    if deletions or table is None:
        return s.translate(table, deletions)
    else:
        # Add s[:0] so that if s is Unicode and table is an 8-bit string,
        # table is converted to Unicode.  This means that table *cannot*
        # be a dictionary -- for that feature, use u.translate() directly.
        return s.translate(table + s[:0])

# Capitalize a string, e.g. "aBc  dEf" -> "Abc  def".
def capitalize(s):
    """capitalize(s) -> string

    Return a copy of the string s with only its first character
    capitalized.

    """
    return s.capitalize()

# Substring replacement (global)
def replace(s, old, new, maxreplace=-1):
    """replace (str, old, new[, maxreplace]) -> string

    Return a copy of string str with all occurrences of substring
    old replaced by new. If the optional argument maxreplace is
    given, only the first maxreplace occurrences are replaced.

    """
    return s.replace(old, new, maxreplace)


# Try importing optional built-in module "strop" -- if it exists,
# it redefines some string operations that are 100-1000 times faster.
# It also defines values for whitespace, lowercase and uppercase
# that match <ctype.h>'s definitions.

try:
    from strop import maketrans, lowercase, uppercase, whitespace
    letters = lowercase + uppercase
except ImportError:
    pass                                          # Use the original versions

########################################################################
# the Formatter class
# see PEP 3101 for details and purpose of this class

# The hard parts are reused from the C implementation.  They're exposed as "_"
# prefixed methods of str and unicode.

# The overall parser is implemented in str._formatter_parser.
# The field name parser is implemented in str._formatter_field_name_split

class Formatter(object):
    def format(self, format_string, *args, **kwargs):
        return self.vformat(format_string, args, kwargs)

    def vformat(self, format_string, args, kwargs):
        used_args = set()
        result = self._vformat(format_string, args, kwargs, used_args, 2)
        self.check_unused_args(used_args, args, kwargs)
        return result

    def _vformat(self, format_string, args, kwargs, used_args, recursion_depth):
        if recursion_depth < 0:
            raise ValueError('Max string recursion exceeded')
        result = []
        for literal_text, field_name, format_spec, conversion in \
                self.parse(format_string):

            # output the literal text
            if literal_text:
                result.append(literal_text)

            # if there's a field, output it
            if field_name is not None:
                # this is some markup, find the object and do
                #  the formatting

                # given the field_name, find the object it references
                #  and the argument it came from
                obj, arg_used = self.get_field(field_name, args, kwargs)
                used_args.add(arg_used)

                # do any conversion on the resulting object
                obj = self.convert_field(obj, conversion)

                # expand the format spec, if needed
                format_spec = self._vformat(format_spec, args, kwargs,
                                            used_args, recursion_depth-1)

                # format the object and append to the result
                result.append(self.format_field(obj, format_spec))

        return ''.join(result)


    def get_value(self, key, args, kwargs):
        if isinstance(key, (int, long)):
            return args[key]
        else:
            return kwargs[key]


    def check_unused_args(self, used_args, args, kwargs):
        pass


    def format_field(self, value, format_spec):
        return format(value, format_spec)


    def convert_field(self, value, conversion):
        # do any conversion on the resulting object
        if conversion == 'r':
            return repr(value)
        elif conversion == 's':
            return str(value)
        elif conversion is None:
            return value
        raise ValueError("Unknown conversion specifier {0!s}".format(conversion))


    # returns an iterable that contains tuples of the form:
    # (literal_text, field_name, format_spec, conversion)
    # literal_text can be zero length
    # field_name can be None, in which case there's no
    #  object to format and output
    # if field_name is not None, it is looked up, formatted
    #  with format_spec and conversion and then used
    def parse(self, format_string):
        return format_string._formatter_parser()


    # given a field_name, find the object it references.
    #  field_name:   the field being looked up, e.g. "0.name"
    #                 or "lookup[3]"
    #  used_args:    a set of which args have been used
    #  args, kwargs: as passed in to vformat
    def get_field(self, field_name, args, kwargs):
        first, rest = field_name._formatter_field_name_split()

        obj = self.get_value(first, args, kwargs)

        # loop through the rest of the field_name, doing
        #  getattr or getitem as needed
        for is_attr, i in rest:
            if is_attr:
                obj = getattr(obj, i)
            else:
                obj = obj[i]

        return obj, first



# This file is imported from within the debugger

from kdevpdb import kdevOutputFormatter

__kdevpython_builtin_locals = locals

# TODO: weakref those, but python can't in general :(
objectTable = {}

def cleanup():
    objectTable.clear()

def format_locals(locals_):
    '''Print local variables in a machine-readable format'''
    cleanup()
    for key, value in locals_.iteritems():
        if key == '__kdevpython_debugger_utils':
            continue
        value = str(value).replace('\n', r'\n')
        if len(value) > 120:
            value = value[:120] + "..."
        print "%s => %s" % (key, value)

def format_ptr_children(ptr):
    try:
        expr = objectTable[ptr]
    except KeyError:
        print "Address of object not in memory any more";
        return
    format_object_children(expr)

def format_object_children(expr):
    if type(expr) == set:
        expr = list(expr)
    
    output = []
    if type(expr) == list:
        for i in range(len(expr)):
            output.append('ptr:<%s> [%s] => %s' % (id(expr[i]), i, str(expr[i]).replace('\n', r'\n')))
            objectTable[id(expr[i])] = expr[i]
    elif type(expr) == dict:
        for k, v in expr.iteritems():
            output.append('ptr:<%s> [%s] => %s' % (id(v), str(k).replace('\n', r'\n'), str(v).replace('\n', r'\n')))
            objectTable[id(v)] = v
    else:
        for i in dir(expr):
            obj = getattr(expr, i)
            output.append('ptr:<%s> .%s => %s' % (id(obj), i, str(obj).replace('\n', r'\n')))
            objectTable[id(obj)] = obj
    print '\n'.join(output)




# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file 'mainwindow.ui'
#
# Created: Sun Mar 11 03:52:59 2012
#      by: PyQt4 UI code generator 4.9
#
# WARNING! All changes made in this file will be lost!

from PyQt4 import QtCore, QtGui

try:
    _fromUtf8 = QtCore.QString.fromUtf8
except AttributeError:
    _fromUtf8 = lambda s: s

class Ui_MainWindow(object):
    def setupUi(self, MainWindow):
        MainWindow.setObjectName(_fromUtf8("MainWindow"))
        MainWindow.resize(294, 123)
        self.centralwidget = QtGui.QWidget(MainWindow)
        self.centralwidget.setObjectName(_fromUtf8("centralwidget"))
        self.verticalLayout = QtGui.QVBoxLayout(self.centralwidget)
        self.verticalLayout.setObjectName(_fromUtf8("verticalLayout"))
        self.pushButton = QtGui.QPushButton(self.centralwidget)
        self.pushButton.setObjectName(_fromUtf8("pushButton"))
        self.verticalLayout.addWidget(self.pushButton)
        self.progressBar = QtGui.QProgressBar(self.centralwidget)
        self.progressBar.setProperty("value", 24)
        self.progressBar.setObjectName(_fromUtf8("progressBar"))
        self.verticalLayout.addWidget(self.progressBar)
        spacerItem = QtGui.QSpacerItem(20, 40, QtGui.QSizePolicy.Minimum, QtGui.QSizePolicy.Expanding)
        self.verticalLayout.addItem(spacerItem)
        MainWindow.setCentralWidget(self.centralwidget)
        self.menubar = QtGui.QMenuBar(MainWindow)
        self.menubar.setGeometry(QtCore.QRect(0, 0, 294, 22))
        self.menubar.setObjectName(_fromUtf8("menubar"))
        self.menuFile = QtGui.QMenu(self.menubar)
        self.menuFile.setObjectName(_fromUtf8("menuFile"))
        MainWindow.setMenuBar(self.menubar)
        self.statusbar = QtGui.QStatusBar(MainWindow)
        self.statusbar.setObjectName(_fromUtf8("statusbar"))
        MainWindow.setStatusBar(self.statusbar)
        self.actionQuit = QtGui.QAction(MainWindow)
        self.actionQuit.setObjectName(_fromUtf8("actionQuit"))
        self.menuFile.addAction(self.actionQuit)
        self.menubar.addAction(self.menuFile.menuAction())

        self.retranslateUi(MainWindow)
        QtCore.QObject.connect(self.actionQuit, QtCore.SIGNAL(_fromUtf8("activated()")), MainWindow.close)
        QtCore.QMetaObject.connectSlotsByName(MainWindow)

    def retranslateUi(self, MainWindow):
        MainWindow.setWindowTitle(QtGui.QApplication.translate("MainWindow", "MainWindow", None, QtGui.QApplication.UnicodeUTF8))
        self.pushButton.setText(QtGui.QApplication.translate("MainWindow", "Click Me!", None, QtGui.QApplication.UnicodeUTF8))
        self.menuFile.setTitle(QtGui.QApplication.translate("MainWindow", "File", None, QtGui.QApplication.UnicodeUTF8))
        self.actionQuit.setText(QtGui.QApplication.translate("MainWindow", "Quit", None, QtGui.QApplication.UnicodeUTF8))




#!/usr/bin/env python2.7
# -*- coding: utf-8 -*-
""":synopsis: Future statement definitions


:mod:`__future__` is a real module, and serves three purposes:

* To avoid confusing existing tools that analyze import statements and expect to
find the modules they're importing.

* To ensure that :ref:`future statements <future>` run under releases prior to
2.1 at least yield runtime exceptions (the import of :mod:`__future__` will
fail, because there was no module of that name prior to 2.1).

* To document when incompatible changes were introduced, and when they will be
--- or were --- made mandatory.  This is a form of executable documentation, and
can be inspected programmatically via importing :mod:`__future__` and examining
its contents.

Each statement in :file:`__future__.py` is of the form::

FeatureName = _Feature(OptionalRelease, MandatoryRelease,
CompilerFlag)


where, normally, *OptionalRelease* is less than *MandatoryRelease*, and both are
5-tuples of the same form as ``sys.version_info``::

(PY_MAJOR_VERSION, # the 2 in 2.1.0a3; an int
PY_MINOR_VERSION, # the 1; an int
PY_MICRO_VERSION, # the 0; an int
PY_RELEASE_LEVEL, # "alpha", "beta", "candidate" or "final"; string
PY_RELEASE_SERIAL # the 3; an int
)

*OptionalRelease* records the first release in which the feature was accepted.

In the case of a *MandatoryRelease* that has not yet occurred,
*MandatoryRelease* predicts the release in which the feature will become part of
the language.

Else *MandatoryRelease* records when the feature became part of the language; in
releases at or after that, modules no longer need a future statement to use the
feature in question, but may continue to use such imports.

*MandatoryRelease* may also be ``None``, meaning that a planned feature got
dropped.

Instances of class :class:`_Feature` have two corresponding methods,
:meth:`getOptionalRelease` and :meth:`getMandatoryRelease`.

*CompilerFlag* is the (bitfield) flag that should be passed in the fourth
argument to the built-in function :func:`compile` to enable the feature in
dynamically compiled code.  This flag is stored in the :attr:`compiler_flag`
attribute on :class:`_Feature` instances.

No feature description will ever be deleted from :mod:`__future__`. Since its
introduction in Python 2.1 the following features have found their way into the
language using this mechanism:

+------------------+-------------+--------------+---------------------------------------------+
| feature          | optional in | mandatory in | effect                                      |
+==================+=============+==============+=============================================+
| nested_scopes    | 2.1.0b1     | 2.2          | :pep:`227`:                                 |
|                  |             |              | *Statically Nested Scopes*                  |
+------------------+-------------+--------------+---------------------------------------------+
| generators       | 2.2.0a1     | 2.3          | :pep:`255`:                                 |
|                  |             |              | *Simple Generators*                         |
+------------------+-------------+--------------+---------------------------------------------+
| division         | 2.2.0a2     | 3.0          | :pep:`238`:                                 |
|                  |             |              | *Changing the Division Operator*            |
+------------------+-------------+--------------+---------------------------------------------+
| absolute_import  | 2.5.0a1     | 2.7          | :pep:`328`:                                 |
|                  |             |              | *Imports: Multi-Line and Absolute/Relative* |
+------------------+-------------+--------------+---------------------------------------------+
| with_statement   | 2.5.0a1     | 2.6          | :pep:`343`:                                 |
|                  |             |              | *The "with" Statement*                      |
+------------------+-------------+--------------+---------------------------------------------+
| print_function   | 2.6.0a2     | 3.0          | :pep:`3105`:                                |
|                  |             |              | *Make print a function*                     |
+------------------+-------------+--------------+---------------------------------------------+
| unicode_literals | 2.6.0a2     | 3.0          | :pep:`3112`:                                |
|                  |             |              | *Bytes literals in Python 3000*             |
+------------------+-------------+--------------+---------------------------------------------+

"""

def nested_scopes(): pass
def generators(): pass
def print_function(): pass
def division(): pass
def absolute_import(): pass
def with_statement(): pass
def unicode_literals(): pass



def global_func():
    return

class some_class():
    def __init__(self):
        bar = None
        self.foo = bar

    def member_func1(self):
        baz = None
        return baz

    def member_func2(self):
        baz = None
        return baz


#!/usr/bin/env python

import numpy
import types
import re

def indent(text):
    result = ""
    for line in text.split('\n'):
        result += "    " + line + "\n"
    return result

def get_indent(string):
    string = string.split("\n")[0]
    indent = 0
    for char in string:
        if char in [' ', '\t']:
            indent += 1
        else:
            return indent
    return 0

def remove_indent(string):
    if type(string) == types.StringType:
        string = string.split("\n")
        max_remove_indent = get_indent(string[0])
        result = ""
        for line in string:
            for offset in xrange(0, len(line)):
                if line[offset] not in [' ', '\t'] or offset > max_remove_indent:
                    result += line[offset:] + "\n"
                    break
        return result
    else:
        return string

def escape_docstring(string):
    if string:
        return string.replace('"""', '\\"\\"\\"')
    else:
        return string


global in_class
in_class = 0

def make_documentation(class_or_module):
    global in_class
    result = ""
    for item_name in dir(class_or_module):
        if item_name in ['__abstractmethods__', '__class__']:
            continue
        if item_name[:1] == '_':
            # skip private properties and stuff like __get__
            continue
        item = getattr(class_or_module, item_name)
        if type(item) in [types.FunctionType, types.BuiltinFunctionType, types.UnboundMethodType] \
           or str(type(item)) in ['<type \'method_descriptor\'>', '<type \'wrapper_descriptor\'>', '<type \'numpy.ufunc\'>']:
            parameters, returnStmt = try_parse_func_docstring(item.__doc__, item_name)
            parameters = parameters if parameters is not None else []
            if in_class > 0:
                parameters.insert(0, 'self')
            result += "def %s(%s):\n" % ( str(item_name), ','.join(parameters) )
            result += indent('"""%s"""\n\n' % remove_indent(escape_docstring(item.__doc__)))
            result += indent("return %s" % returnStmt)
        elif type(item) == types.TypeType:
            result += "class %s:\n" % item_name
            in_class += 1
            result += indent(make_documentation(item)) + "\n"
            in_class -= 1
        else:
            try:
                if type(item) in [types.TypeType, types.ClassType]:
                    default_value = str(item.__name__ + "()")
                else:
                    default_value = str(type(item)())
                if default_value == "":
                    raise TypeError()
                if default_value.find('<') != -1:
                    raise TypeError()
            except TypeError:
                default_value = "None"
            result += "%s = %s\n" % (item_name, default_value)
    if result == "":
        result = "pass"
    return result

def sanitizeParamName(name):
    parameter_name = name.replace(' ', '').replace('\t', '').replace('\\', '') \
               .replace('.', '_').replace('[', '').replace(']', '') \
               .replace('*', '').replace('-', '_').replace('{', '').replace('}', '') \
               .replace('(', '').replace(')', '')
    try:
        t = int(parameter_name[0])
        parameter_name = '_' + parameter_name
    except:
        pass
    return parameter_name

def try_parse_func_docstring(docstring, funcname):
    if type(docstring) == types.StringType:
        indent = 0
        atLineBeginning = True
        paramListBegin = paramListEnd = False
        returnTypeBegin = returnTypeEnd = False
        atPartBeginning = 2
        returnType = "None"
        for offset in xrange(0, len(docstring)):
            if docstring[offset] == "\n":
                indent = 0
            if docstring[offset] in [' ', '\t'] and atLineBeginning:
                indent += 1
            else:
                atLineBeginning = False
            
            if paramListEnd == False:
                if docstring[offset:offset+len("Parameters")] == "Parameters":
                    paramListBegin = offset
                if paramListBegin is not False and docstring[offset] == "\n" and atPartBeginning != 0:
                    atPartBeginning -= 1
                if docstring[offset:offset+len("---")] == "---" and atPartBeginning == 0:
                    paramListEnd = offset
                    break
            if returnTypeEnd == False:
                if docstring[offset:offset+len("Returns")] == "Returns":
                    returnTypeBegin = offset
        relevantPart = docstring[paramListBegin:paramListEnd].split("\n")[2:]
        if returnTypeBegin is not False:
            try:
                returnTypeLine = docstring[returnTypeBegin:].split('\n')[2].split(' : ')[1].split(' ')[0].split(',')[0]
                returnType = sanitizeParamName(returnTypeLine) + "()"
            except IndexError:
                pass
        if len(relevantPart):
            firstIndent = get_indent(relevantPart[0])
            parameter_name_list = []
            for line_index in xrange(0, len(relevantPart)):
                if get_indent(relevantPart[line_index]) == firstIndent:
                    s = relevantPart[line_index].split(' : ')
                    if len(s) == 2:
                        name = s[0]
                        type_string = s[1]
                        doc_for_param = None # TODO extract this, and display it in some way... or not
                        parameter_name = sanitizeParamName(name)
                        if parameter_name.find('...') != -1:
                            parameter_name = 'more'
                        parameter_name = parameter_name.replace('`', '')
                        parameter_name_list.append(parameter_name)
            return parameter_name_list, returnType
        else:
            try:
                firstType = docstring.split("\n")[0].split('.')[-1]
                if firstType.find(funcname) == -1:
                    raise IndexError()
                firstType = firstType.split('->')[0]
                firstType = firstType.split('(')[1:]
                firstType = ')'.join('('.join(firstType).split(')')[:-1])
                paramList = firstType.split(',')
                cleanedParamList = []
                for item in paramList:
                    if item.find('...') == -1:
                        cleanedParamList.append(item)
                return [sanitizeParamName(x) for x in cleanedParamList], "None"
            except IndexError:
                return [], "None"
    else:
        return [], "None"

if __name__ == '__main__':
    print make_documentation(numpy)


import sys
from PyQt4 import QtGui
import mainwindow

class MainWindow(QtGui.QMainWindow):
    def __init__(self):
        super(MainWindow, self).__init__()
        self.ui = mainwindow.Ui_MainWindow()
        self.ui.setupUi(self)
        self.ui.pushButton.clicked.connect(self.advanceSlider)

    def advanceSlider(self):
        self.ui.progressBar.setValue(self.ui.progressBar.value() + 1)

app = QtGui.QApplication(sys.argv)

my_mainWindow = MainWindow()
my_mainWindow.show()

sys.exit(app.exec_())